# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/audit/v1/audit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cerbos.engine.v1 import engine_pb2 as cerbos_dot_engine_dot_v1_dot_engine__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63\x65rbos/audit/v1/audit.proto\x12\x0f\x63\x65rbos.audit.v1\x1a\x1d\x63\x65rbos/engine/v1/engine.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xec\x02\n\x0e\x41\x63\x63\x65ssLogEntry\x12\x17\n\x07\x63\x61ll_id\x18\x01 \x01(\tR\x06\x63\x61llId\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12)\n\x04peer\x18\x03 \x01(\x0b\x32\x15.cerbos.audit.v1.PeerR\x04peer\x12I\n\x08metadata\x18\x04 \x03(\x0b\x32-.cerbos.audit.v1.AccessLogEntry.MetadataEntryR\x08metadata\x12\x16\n\x06method\x18\x05 \x01(\tR\x06method\x12\x1f\n\x0bstatus_code\x18\x06 \x01(\rR\nstatusCode\x1aX\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\x1b.cerbos.audit.v1.MetaValuesR\x05value:\x02\x38\x01\"\xb8\x07\n\x10\x44\x65\x63isionLogEntry\x12\x17\n\x07\x63\x61ll_id\x18\x01 \x01(\tR\x06\x63\x61llId\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12)\n\x04peer\x18\x03 \x01(\x0b\x32\x15.cerbos.audit.v1.PeerR\x04peer\x12\x34\n\x06inputs\x18\x04 \x03(\x0b\x32\x1c.cerbos.engine.v1.CheckInputR\x06inputs\x12\x37\n\x07outputs\x18\x05 \x03(\x0b\x32\x1d.cerbos.engine.v1.CheckOutputR\x07outputs\x12\x14\n\x05\x65rror\x18\x06 \x01(\tR\x05\x65rror\x12[\n\x0f\x63heck_resources\x18\x07 \x01(\x0b\x32\x30.cerbos.audit.v1.DecisionLogEntry.CheckResourcesH\x00R\x0e\x63heckResources\x12X\n\x0eplan_resources\x18\x08 \x01(\x0b\x32/.cerbos.audit.v1.DecisionLogEntry.PlanResourcesH\x00R\rplanResources\x12K\n\x08metadata\x18\x0f \x03(\x0b\x32/.cerbos.audit.v1.DecisionLogEntry.MetadataEntryR\x08metadata\x1a\x95\x01\n\x0e\x43heckResources\x12\x34\n\x06inputs\x18\x01 \x03(\x0b\x32\x1c.cerbos.engine.v1.CheckInputR\x06inputs\x12\x37\n\x07outputs\x18\x02 \x03(\x0b\x32\x1d.cerbos.engine.v1.CheckOutputR\x07outputs\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\x1a\xa0\x01\n\rPlanResources\x12:\n\x05input\x18\x01 \x01(\x0b\x32$.cerbos.engine.v1.PlanResourcesInputR\x05input\x12=\n\x06output\x18\x02 \x01(\x0b\x32%.cerbos.engine.v1.PlanResourcesOutputR\x06output\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\x1aX\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\x1b.cerbos.audit.v1.MetaValuesR\x05value:\x02\x38\x01\x42\x08\n\x06method\"$\n\nMetaValues\x12\x16\n\x06values\x18\x01 \x03(\tR\x06values\"\x81\x01\n\x04Peer\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x1b\n\tauth_info\x18\x02 \x01(\tR\x08\x61uthInfo\x12\x1d\n\nuser_agent\x18\x03 \x01(\tR\tuserAgent\x12#\n\rforwarded_for\x18\x04 \x01(\tR\x0c\x66orwardedForBk\n\x17\x64\x65v.cerbos.api.v1.auditZ:github.com/cerbos/cerbos/api/genpb/cerbos/audit/v1;auditv1\xaa\x02\x13\x43\x65rbos.Api.V1.Auditb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.audit.v1.audit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027dev.cerbos.api.v1.auditZ:github.com/cerbos/cerbos/api/genpb/cerbos/audit/v1;auditv1\252\002\023Cerbos.Api.V1.Audit'
  _ACCESSLOGENTRY_METADATAENTRY._options = None
  _ACCESSLOGENTRY_METADATAENTRY._serialized_options = b'8\001'
  _DECISIONLOGENTRY_METADATAENTRY._options = None
  _DECISIONLOGENTRY_METADATAENTRY._serialized_options = b'8\001'
  _globals['_ACCESSLOGENTRY']._serialized_start=113
  _globals['_ACCESSLOGENTRY']._serialized_end=477
  _globals['_ACCESSLOGENTRY_METADATAENTRY']._serialized_start=389
  _globals['_ACCESSLOGENTRY_METADATAENTRY']._serialized_end=477
  _globals['_DECISIONLOGENTRY']._serialized_start=480
  _globals['_DECISIONLOGENTRY']._serialized_end=1432
  _globals['_DECISIONLOGENTRY_CHECKRESOURCES']._serialized_start=1020
  _globals['_DECISIONLOGENTRY_CHECKRESOURCES']._serialized_end=1169
  _globals['_DECISIONLOGENTRY_PLANRESOURCES']._serialized_start=1172
  _globals['_DECISIONLOGENTRY_PLANRESOURCES']._serialized_end=1332
  _globals['_DECISIONLOGENTRY_METADATAENTRY']._serialized_start=389
  _globals['_DECISIONLOGENTRY_METADATAENTRY']._serialized_end=477
  _globals['_METAVALUES']._serialized_start=1434
  _globals['_METAVALUES']._serialized_end=1470
  _globals['_PEER']._serialized_start=1473
  _globals['_PEER']._serialized_end=1602
# @@protoc_insertion_point(module_scope)
