from google.protobuf import descriptor_pb2 as _descriptor_pb2
from protoc_gen_openapiv2.options import openapiv2_pb2 as _openapiv2_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
OPENAPIV2_SWAGGER_FIELD_NUMBER: _ClassVar[int]
openapiv2_swagger: _descriptor.FieldDescriptor
OPENAPIV2_OPERATION_FIELD_NUMBER: _ClassVar[int]
openapiv2_operation: _descriptor.FieldDescriptor
OPENAPIV2_SCHEMA_FIELD_NUMBER: _ClassVar[int]
openapiv2_schema: _descriptor.FieldDescriptor
OPENAPIV2_TAG_FIELD_NUMBER: _ClassVar[int]
openapiv2_tag: _descriptor.FieldDescriptor
OPENAPIV2_FIELD_FIELD_NUMBER: _ClassVar[int]
openapiv2_field: _descriptor.FieldDescriptor
