# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/telemetry/v1/telemetry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cerbos/telemetry/v1/telemetry.proto\x12\x13\x63\x65rbos.telemetry.v1\x1a\x1egoogle/protobuf/duration.proto\"\xf6\x12\n\x0cServerLaunch\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12@\n\x06source\x18\x02 \x01(\x0b\x32(.cerbos.telemetry.v1.ServerLaunch.SourceR\x06source\x12\x46\n\x08\x66\x65\x61tures\x18\x03 \x01(\x0b\x32*.cerbos.telemetry.v1.ServerLaunch.FeaturesR\x08\x66\x65\x61tures\x12=\n\x05stats\x18\x04 \x01(\x0b\x32\'.cerbos.telemetry.v1.ServerLaunch.StatsR\x05stats\x1a\xa9\x01\n\x06\x43\x65rbos\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x16\n\x06\x63ommit\x18\x02 \x01(\tR\x06\x63ommit\x12\x1d\n\nbuild_date\x18\x03 \x01(\tR\tbuildDate\x12%\n\x0emodule_version\x18\x04 \x01(\tR\rmoduleVersion\x12\'\n\x0fmodule_checksum\x18\x05 \x01(\tR\x0emoduleChecksum\x1a\x89\x01\n\x06Source\x12@\n\x06\x63\x65rbos\x18\x01 \x01(\x0b\x32(.cerbos.telemetry.v1.ServerLaunch.CerbosR\x06\x63\x65rbos\x12\x0e\n\x02os\x18\x02 \x01(\tR\x02os\x12\x12\n\x04\x61rch\x18\x03 \x01(\tR\x04\x61rch\x12\x19\n\x08num_cpus\x18\x04 \x01(\rR\x07numCpus\x1a\x94\t\n\x08\x46\x65\x61tures\x12\x46\n\x05\x61udit\x18\x01 \x01(\x0b\x32\x30.cerbos.telemetry.v1.ServerLaunch.Features.AuditR\x05\x61udit\x12I\n\x06schema\x18\x02 \x01(\x0b\x32\x31.cerbos.telemetry.v1.ServerLaunch.Features.SchemaR\x06schema\x12P\n\tadmin_api\x18\x03 \x01(\x0b\x32\x33.cerbos.telemetry.v1.ServerLaunch.Features.AdminApiR\x08\x61\x64minApi\x12L\n\x07storage\x18\x04 \x01(\x0b\x32\x32.cerbos.telemetry.v1.ServerLaunch.Features.StorageR\x07storage\x1a;\n\x05\x41udit\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12\x18\n\x07\x62\x61\x63kend\x18\x02 \x01(\tR\x07\x62\x61\x63kend\x1a*\n\x06Schema\x12 \n\x0b\x65nforcement\x18\x01 \x01(\tR\x0b\x65nforcement\x1a$\n\x08\x41\x64minApi\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x1a\xc5\x05\n\x07Storage\x12\x16\n\x06\x64river\x18\x01 \x01(\tR\x06\x64river\x12M\n\x04\x64isk\x18\x02 \x01(\x0b\x32\x37.cerbos.telemetry.v1.ServerLaunch.Features.Storage.DiskH\x00R\x04\x64isk\x12J\n\x03git\x18\x03 \x01(\x0b\x32\x36.cerbos.telemetry.v1.ServerLaunch.Features.Storage.GitH\x00R\x03git\x12M\n\x04\x62lob\x18\x04 \x01(\x0b\x32\x37.cerbos.telemetry.v1.ServerLaunch.Features.Storage.BlobH\x00R\x04\x62lob\x12S\n\x06\x62undle\x18\x05 \x01(\x0b\x32\x39.cerbos.telemetry.v1.ServerLaunch.Features.Storage.BundleH\x00R\x06\x62undle\x1a\x1c\n\x04\x44isk\x12\x14\n\x05watch\x18\x01 \x01(\x08R\x05watch\x1au\n\x03Git\x12\x1a\n\x08protocol\x18\x01 \x01(\tR\x08protocol\x12\x12\n\x04\x61uth\x18\x02 \x01(\x08R\x04\x61uth\x12>\n\rpoll_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cpollInterval\x1a\x62\n\x04\x42lob\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12>\n\rpoll_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cpollInterval\x1a\x61\n\x06\x42undle\x12\x15\n\x06pdp_id\x18\x01 \x01(\tR\x05pdpId\x12#\n\rbundle_source\x18\x02 \x01(\tR\x0c\x62undleSource\x12\x1b\n\tclient_id\x18\x03 \x01(\tR\x08\x63lientIdB\x07\n\x05store\x1a\xb3\x05\n\x05Stats\x12\x46\n\x06policy\x18\x01 \x01(\x0b\x32..cerbos.telemetry.v1.ServerLaunch.Stats.PolicyR\x06policy\x12\x46\n\x06schema\x18\x02 \x01(\x0b\x32..cerbos.telemetry.v1.ServerLaunch.Stats.SchemaR\x06schema\x1a\xf9\x03\n\x06Policy\x12O\n\x05\x63ount\x18\x01 \x03(\x0b\x32\x39.cerbos.telemetry.v1.ServerLaunch.Stats.Policy.CountEntryR\x05\x63ount\x12\x66\n\x0e\x61vg_rule_count\x18\x02 \x03(\x0b\x32@.cerbos.telemetry.v1.ServerLaunch.Stats.Policy.AvgRuleCountEntryR\x0c\x61vgRuleCount\x12u\n\x13\x61vg_condition_count\x18\x03 \x03(\x0b\x32\x45.cerbos.telemetry.v1.ServerLaunch.Stats.Policy.AvgConditionCountEntryR\x11\x61vgConditionCount\x1a\x38\n\nCountEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\rR\x05value:\x02\x38\x01\x1a?\n\x11\x41vgRuleCountEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\x44\n\x16\x41vgConditionCountEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\x1e\n\x06Schema\x12\x14\n\x05\x63ount\x18\x01 \x01(\rR\x05\x63ount\"\x80\x01\n\nServerStop\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12%\n\x0erequests_total\x18\x03 \x01(\x04R\rrequestsTotal\"\xfe\x02\n\x05\x45vent\x12K\n\x0c\x61pi_activity\x18\x01 \x01(\x0b\x32&.cerbos.telemetry.v1.Event.ApiActivityH\x00R\x0b\x61piActivity\x1a\x33\n\tCountStat\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05\x63ount\x18\x02 \x01(\x04R\x05\x63ount\x1a\xea\x01\n\x0b\x41piActivity\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12G\n\x0cmethod_calls\x18\x03 \x03(\x0b\x32$.cerbos.telemetry.v1.Event.CountStatR\x0bmethodCalls\x12\x45\n\x0buser_agents\x18\x04 \x03(\x0b\x32$.cerbos.telemetry.v1.Event.CountStatR\nuserAgentsB\x06\n\x04\x64\x61taB{\n\x1b\x64\x65v.cerbos.api.v1.telemetryZBgithub.com/cerbos/cerbos/api/genpb/cerbos/telemetry/v1;telemetryv1\xaa\x02\x17\x43\x65rbos.Api.V1.Telemetryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.telemetry.v1.telemetry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033dev.cerbos.api.v1.telemetryZBgithub.com/cerbos/cerbos/api/genpb/cerbos/telemetry/v1;telemetryv1\252\002\027Cerbos.Api.V1.Telemetry'
  _SERVERLAUNCH_STATS_POLICY_COUNTENTRY._options = None
  _SERVERLAUNCH_STATS_POLICY_COUNTENTRY._serialized_options = b'8\001'
  _SERVERLAUNCH_STATS_POLICY_AVGRULECOUNTENTRY._options = None
  _SERVERLAUNCH_STATS_POLICY_AVGRULECOUNTENTRY._serialized_options = b'8\001'
  _SERVERLAUNCH_STATS_POLICY_AVGCONDITIONCOUNTENTRY._options = None
  _SERVERLAUNCH_STATS_POLICY_AVGCONDITIONCOUNTENTRY._serialized_options = b'8\001'
  _globals['_SERVERLAUNCH']._serialized_start=93
  _globals['_SERVERLAUNCH']._serialized_end=2515
  _globals['_SERVERLAUNCH_CERBOS']._serialized_start=337
  _globals['_SERVERLAUNCH_CERBOS']._serialized_end=506
  _globals['_SERVERLAUNCH_SOURCE']._serialized_start=509
  _globals['_SERVERLAUNCH_SOURCE']._serialized_end=646
  _globals['_SERVERLAUNCH_FEATURES']._serialized_start=649
  _globals['_SERVERLAUNCH_FEATURES']._serialized_end=1821
  _globals['_SERVERLAUNCH_FEATURES_AUDIT']._serialized_start=968
  _globals['_SERVERLAUNCH_FEATURES_AUDIT']._serialized_end=1027
  _globals['_SERVERLAUNCH_FEATURES_SCHEMA']._serialized_start=1029
  _globals['_SERVERLAUNCH_FEATURES_SCHEMA']._serialized_end=1071
  _globals['_SERVERLAUNCH_FEATURES_ADMINAPI']._serialized_start=1073
  _globals['_SERVERLAUNCH_FEATURES_ADMINAPI']._serialized_end=1109
  _globals['_SERVERLAUNCH_FEATURES_STORAGE']._serialized_start=1112
  _globals['_SERVERLAUNCH_FEATURES_STORAGE']._serialized_end=1821
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_DISK']._serialized_start=1466
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_DISK']._serialized_end=1494
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_GIT']._serialized_start=1496
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_GIT']._serialized_end=1613
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_BLOB']._serialized_start=1615
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_BLOB']._serialized_end=1713
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_BUNDLE']._serialized_start=1715
  _globals['_SERVERLAUNCH_FEATURES_STORAGE_BUNDLE']._serialized_end=1812
  _globals['_SERVERLAUNCH_STATS']._serialized_start=1824
  _globals['_SERVERLAUNCH_STATS']._serialized_end=2515
  _globals['_SERVERLAUNCH_STATS_POLICY']._serialized_start=1978
  _globals['_SERVERLAUNCH_STATS_POLICY']._serialized_end=2483
  _globals['_SERVERLAUNCH_STATS_POLICY_COUNTENTRY']._serialized_start=2292
  _globals['_SERVERLAUNCH_STATS_POLICY_COUNTENTRY']._serialized_end=2348
  _globals['_SERVERLAUNCH_STATS_POLICY_AVGRULECOUNTENTRY']._serialized_start=2350
  _globals['_SERVERLAUNCH_STATS_POLICY_AVGRULECOUNTENTRY']._serialized_end=2413
  _globals['_SERVERLAUNCH_STATS_POLICY_AVGCONDITIONCOUNTENTRY']._serialized_start=2415
  _globals['_SERVERLAUNCH_STATS_POLICY_AVGCONDITIONCOUNTENTRY']._serialized_end=2483
  _globals['_SERVERLAUNCH_STATS_SCHEMA']._serialized_start=2485
  _globals['_SERVERLAUNCH_STATS_SCHEMA']._serialized_end=2515
  _globals['_SERVERSTOP']._serialized_start=2518
  _globals['_SERVERSTOP']._serialized_end=2646
  _globals['_EVENT']._serialized_start=2649
  _globals['_EVENT']._serialized_end=3031
  _globals['_EVENT_COUNTSTAT']._serialized_start=2735
  _globals['_EVENT_COUNTSTAT']._serialized_end=2786
  _globals['_EVENT_APIACTIVITY']._serialized_start=2789
  _globals['_EVENT_APIACTIVITY']._serialized_end=3023
# @@protoc_insertion_point(module_scope)
