# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/response/v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cerbos.audit.v1 import audit_pb2 as cerbos_dot_audit_dot_v1_dot_audit__pb2
from cerbos.effect.v1 import effect_pb2 as cerbos_dot_effect_dot_v1_dot_effect__pb2
from cerbos.engine.v1 import engine_pb2 as cerbos_dot_engine_dot_v1_dot_engine__pb2
from cerbos.policy.v1 import policy_pb2 as cerbos_dot_policy_dot_v1_dot_policy__pb2
from cerbos.schema.v1 import schema_pb2 as cerbos_dot_schema_dot_v1_dot_schema__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cerbos/response/v1/response.proto\x12\x12\x63\x65rbos.response.v1\x1a\x1b\x63\x65rbos/audit/v1/audit.proto\x1a\x1d\x63\x65rbos/effect/v1/effect.proto\x1a\x1d\x63\x65rbos/engine/v1/engine.proto\x1a\x1d\x63\x65rbos/policy/v1/policy.proto\x1a\x1d\x63\x65rbos/schema/v1/schema.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\xb5\x08\n\x15PlanResourcesResponse\x12o\n\nrequest_id\x18\x01 \x01(\tBP\x92\x41M2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\x32\n\x06\x61\x63tion\x18\x02 \x01(\tB\x1a\x92\x41\x17\x32\x06\x41\x63tionJ\r\"view:public\"R\x06\x61\x63tion\x12\x8a\x01\n\rresource_kind\x18\x03 \x01(\tBe\x92\x41\x62\x32\x0eResource kind.J\x0e\"album:object\"\x8a\x01?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$R\x0cresourceKind\x12J\n\x0epolicy_version\x18\x04 \x01(\tB#\x92\x41 2\x13The policy version.J\t\"default\"R\rpolicyVersion\x12J\n\x06\x66ilter\x18\x05 \x01(\x0b\x32%.cerbos.engine.v1.PlanResourcesFilterB\x0b\x92\x41\x08\x32\x06\x46ilterR\x06\x66ilter\x12\x7f\n\x04meta\x18\x06 \x01(\x0b\x32..cerbos.response.v1.PlanResourcesResponse.MetaB;\x92\x41\x38\x32\x36Optional metadata about the request evaluation processR\x04meta\x12\x90\x01\n\x11validation_errors\x18\x07 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB@\x92\x41=2;List of validation errors (if schema validation is enabled)R\x10validationErrors\x1a\xff\x01\n\x04Meta\x12]\n\x0c\x66ilter_debug\x18\x01 \x01(\tB:\x92\x41\x37\x32\x35\x46ilter textual representation for debugging purposes.R\x0b\x66ilterDebug\x12m\n\rmatched_scope\x18\x02 \x01(\tBH\x92\x41\x45\x32\x31Policy scope that matched to produce this effect.J\x10\"acme.corp.base\"R\x0cmatchedScope:)\x92\x41&\n$2\"Metadata about request evaluation.:<\x92\x41\x39\n725Resources query plan response for a set of resources.\"\xc8\x15\n\x18\x43heckResourceSetResponse\x12o\n\nrequest_id\x18\x01 \x01(\tBP\x92\x41M2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\xdb\x02\n\x12resource_instances\x18\x02 \x03(\x0b\x32\x43.cerbos.response.v1.CheckResourceSetResponse.ResourceInstancesEntryB\xe6\x01\x92\x41\xe2\x01\x32KResults for each resource instance, keyed by the ID supplied in the requestJ\x92\x01{\"XX125\":{\"actions\":{\"view:*\":\"EFFECT_ALLOW\", \"comment\": \"EFFECT_ALLOW\"}}, \"XX225\":{\"actions\":{\"view:*\":\"EFFECT_DENY\", \"comment\": \"EFFECT_DENY\"}}}R\x11resourceInstances\x12\x82\x01\n\x04meta\x18\x03 \x01(\x0b\x32\x31.cerbos.response.v1.CheckResourceSetResponse.MetaB;\x92\x41\x38\x32\x36Optional metadata about the request evaluation processR\x04meta\x1a\x8b\x03\n\x0f\x41\x63tionEffectMap\x12\x8e\x01\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32I.cerbos.response.v1.CheckResourceSetResponse.ActionEffectMap.ActionsEntryB)\x92\x41&2$Mapping of each action to an effect.R\x07\x61\x63tions\x12\x90\x01\n\x11validation_errors\x18\x02 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB@\x92\x41=2;List of validation errors (if schema validation is enabled)R\x10validationErrors\x1aT\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x05value:\x02\x38\x01\x1a\x89\x0c\n\x04Meta\x12\xcf\x03\n\x12resource_instances\x18\x01 \x03(\x0b\x32H.cerbos.response.v1.CheckResourceSetResponse.Meta.ResourceInstancesEntryB\xd5\x02\x92\x41\xd1\x02\x32\"Metadata about resource instances.J\xaa\x02{\"XX125\": {\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}, \"effective_derived_roles\": [\"owner\"]}, \"XX225\": {\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}}}R\x11resourceInstances\x1a\x88\x02\n\nEffectMeta\x12o\n\x0ematched_policy\x18\x01 \x01(\tBH\x92\x41\x45\x32+Policy that matched to produce this effect.J\x16\"album:object:default\"R\rmatchedPolicy\x12m\n\rmatched_scope\x18\x02 \x01(\tBH\x92\x41\x45\x32\x31Policy scope that matched to produce this effect.J\x10\"acme.corp.base\"R\x0cmatchedScope:\x1a\x92\x41\x17\n\x15\x32\x13Name of the action.\x1a\xf3\x04\n\nActionMeta\x12\xa7\x02\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32I.cerbos.response.v1.CheckResourceSetResponse.Meta.ActionMeta.ActionsEntryB\xc1\x01\x92\x41\xbd\x01\x32OMetadata about the effect calculated for each action on this resource instance.Jj{\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}R\x07\x61\x63tions\x12\x83\x01\n\x17\x65\x66\x66\x65\x63tive_derived_roles\x18\x02 \x03(\tBK\x92\x41H2;Derived roles that were effective during policy evaluation.J\t[\"owner\"]R\x15\x65\x66\x66\x65\x63tiveDerivedRoles\x1ax\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.cerbos.response.v1.CheckResourceSetResponse.Meta.EffectMetaR\x05value:\x02\x38\x01:;\x92\x41\x38\n624Unique resource instance ID supplied in the request.\x1a\x82\x01\n\x16ResourceInstancesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.cerbos.response.v1.CheckResourceSetResponse.Meta.ActionMetaR\x05value:\x02\x38\x01:)\x92\x41&\n$2\"Metadata about request evaluation.\x1a\x82\x01\n\x16ResourceInstancesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.cerbos.response.v1.CheckResourceSetResponse.ActionEffectMapR\x05value:\x02\x38\x01:9\x92\x41\x36\n422Policy evaluation response for a set of resources.\"\xe5\x06\n\x1a\x43heckResourceBatchResponse\x12o\n\nrequest_id\x18\x01 \x01(\tBP\x92\x41M2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\xb3\x01\n\x07results\x18\x02 \x03(\x0b\x32>.cerbos.response.v1.CheckResourceBatchResponse.ActionEffectMapBY\x92\x41V2\x18Result for each resourceJ:[{\"resourceId\":\"XX125\",\"actions\":{\"view\":\"EFFECT_ALLOW\"}}]R\x07results\x1a\xe2\x03\n\x0f\x41\x63tionEffectMap\x12:\n\x0bresource_id\x18\x01 \x01(\tB\x19\x92\x41\x16\x32\x0bResource IDJ\x07\"XX125\"R\nresourceId\x12\xa9\x01\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32K.cerbos.response.v1.CheckResourceBatchResponse.ActionEffectMap.ActionsEntryBB\x92\x41?2$Mapping of each action to an effect.J\x17{\"view\":\"EFFECT_ALLOW\"}R\x07\x61\x63tions\x12\x90\x01\n\x11validation_errors\x18\x03 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB@\x92\x41=2;List of validation errors (if schema validation is enabled)R\x10validationErrors\x1aT\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x05value:\x02\x38\x01:;\x92\x41\x38\n624Policy evaluation response for a batch of resources.\"\xa6\x17\n\x16\x43heckResourcesResponse\x12o\n\nrequest_id\x18\x01 \x01(\tBP\x92\x41M2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\xe3\x01\n\x07results\x18\x02 \x03(\x0b\x32\x36.cerbos.response.v1.CheckResourcesResponse.ResultEntryB\x90\x01\x92\x41\x8c\x01\x32\x18Result for each resourceJp[{\"resource\": {\"Id\":\"XX125\", \"kind\":\"album:object\"}, \"actions\":{\"view\":\"EFFECT_ALLOW\",\"comment\":\"EFFECT_DENY\"}}]R\x07results\x1a\x80\x14\n\x0bResultEntry\x12[\n\x08resource\x18\x01 \x01(\x0b\x32?.cerbos.response.v1.CheckResourcesResponse.ResultEntry.ResourceR\x08resource\x12\xa1\x01\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x43.cerbos.response.v1.CheckResourcesResponse.ResultEntry.ActionsEntryBB\x92\x41?2$Mapping of each action to an effect.J\x17{\"view\":\"EFFECT_ALLOW\"}R\x07\x61\x63tions\x12\x90\x01\n\x11validation_errors\x18\x03 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB@\x92\x41=2;List of validation errors (if schema validation is enabled)R\x10validationErrors\x12\x98\x02\n\x04meta\x18\x04 \x01(\x0b\x32;.cerbos.response.v1.CheckResourcesResponse.ResultEntry.MetaB\xc6\x01\x92\x41\xc2\x01\x32 Metadata about policy evaluationJ\x9d\x01{\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}, \"effective_derived_roles\": [\"owner\"]}R\x04meta\x12\xf6\x01\n\x07outputs\x18\x05 \x03(\x0b\x32\x1d.cerbos.engine.v1.OutputEntryB\xbc\x01\x92\x41\xb8\x01\x32,Output for each rule with outputs configuredJ\x87\x01[{\"src\": \"resource.expense.v1/acme#rule-001\", \"val\": \"view_allowed:alice\"}, {\"src\": \"resource.expense.v1/acme#rule-002\", \"val\": \"foo\"}]R\x07outputs\x1a\xff\x04\n\x08Resource\x12\x39\n\x02id\x18\x01 \x01(\tB)\x92\x41&2\x1bID of the resource instanceJ\x07\"XX125\"R\x02id\x12\x93\x01\n\x04kind\x18\x02 \x01(\tB\x7f\x92\x41|2)Name of the resource kind being accessed.J\r\"album:photo\"\x8a\x01?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$R\x04kind\x12\xc5\x01\n\x0epolicy_version\x18\x03 \x01(\tB\x9d\x01\x92\x41\x99\x01\x32|The policy version to use to evaluate this request. If not specified, will default to the server-configured default version.J\t\"default\"\x8a\x01\r^[[:word:]]*$R\rpolicyVersion\x12\xd9\x01\n\x05scope\x18\x04 \x01(\tB\xc2\x01\x92\x41\xbe\x01\x32}A dot-separated scope that describes the hierarchy this resource belongs to. This is used for determining policy inheritance.J\x0b\"acme.corp\"\x8a\x01/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$R\x05scope\x1a\xf0\x06\n\x04Meta\x12\xa6\x02\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32H.cerbos.response.v1.CheckResourcesResponse.ResultEntry.Meta.ActionsEntryB\xc1\x01\x92\x41\xbd\x01\x32OMetadata about the effect calculated for each action on this resource instance.Jj{\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}R\x07\x61\x63tions\x12\x83\x01\n\x17\x65\x66\x66\x65\x63tive_derived_roles\x18\x02 \x03(\tBK\x92\x41H2;Derived roles that were effective during policy evaluation.J\t[\"owner\"]R\x15\x65\x66\x66\x65\x63tiveDerivedRoles\x1a\x88\x02\n\nEffectMeta\x12o\n\x0ematched_policy\x18\x01 \x01(\tBH\x92\x41\x45\x32+Policy that matched to produce this effect.J\x16\"album:object:default\"R\rmatchedPolicy\x12m\n\rmatched_scope\x18\x02 \x01(\tBH\x92\x41\x45\x32\x31Policy scope that matched to produce this effect.J\x10\"acme.corp.base\"R\x0cmatchedScope:\x1a\x92\x41\x17\n\x15\x32\x13Name of the action.\x1a\x82\x01\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\\\n\x05value\x18\x02 \x01(\x0b\x32\x46.cerbos.response.v1.CheckResourcesResponse.ResultEntry.Meta.EffectMetaR\x05value:\x02\x38\x01:)\x92\x41&\n$2\"Metadata about request evaluation.\x1aT\n\x0c\x41\x63tionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x05value:\x02\x38\x01:2\x92\x41/\n-2+Response from the check resources API call.\"\xa7\x01\n\x11PlaygroundFailure\x12\x43\n\x06\x65rrors\x18\x01 \x03(\x0b\x32+.cerbos.response.v1.PlaygroundFailure.ErrorR\x06\x65rrors\x1a\x31\n\x05\x45rror\x12\x12\n\x04\x66ile\x18\x01 \x01(\tR\x04\x66ile\x12\x14\n\x05\x65rror\x18\x02 \x01(\tR\x05\x65rror:\x1a\x92\x41\x17\n\x15\x32\x13Playground response\"\xe8\x01\n\x1aPlaygroundValidateResponse\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.response.v1.PlaygroundFailureH\x00R\x07\x66\x61ilure\x12\x32\n\x07success\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07success:#\x92\x41 \n\x1e\x32\x1cPlayground validate responseB\t\n\x07outcome\"\xc8\x02\n\x16PlaygroundTestResponse\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.response.v1.PlaygroundFailureH\x00R\x07\x66\x61ilure\x12R\n\x07success\x18\x03 \x01(\x0b\x32\x36.cerbos.response.v1.PlaygroundTestResponse.TestResultsH\x00R\x07success\x1a\x46\n\x0bTestResults\x12\x37\n\x07results\x18\x01 \x01(\x0b\x32\x1d.cerbos.policy.v1.TestResultsR\x07results:\x1f\x92\x41\x1c\n\x1a\x32\x18Playground test responseB\t\n\x07outcome\"\xb9\x06\n\x1aPlaygroundEvaluateResponse\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.response.v1.PlaygroundFailureH\x00R\x07\x66\x61ilure\x12Y\n\x07success\x18\x03 \x01(\x0b\x32=.cerbos.response.v1.PlaygroundEvaluateResponse.EvalResultListH\x00R\x07success\x1a\xfe\x01\n\nEvalResult\x12\x16\n\x06\x61\x63tion\x18\x01 \x01(\tR\x06\x61\x63tion\x12\x30\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\x0e\x32\x18.cerbos.effect.v1.EffectR\x06\x65\x66\x66\x65\x63t\x12\x16\n\x06policy\x18\x03 \x01(\tR\x06policy\x12:\n\x17\x65\x66\x66\x65\x63tive_derived_roles\x18\x04 \x03(\tB\x02\x18\x01R\x15\x65\x66\x66\x65\x63tiveDerivedRoles\x12R\n\x11validation_errors\x18\x05 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorB\x02\x18\x01R\x10validationErrors\x1a\xa6\x02\n\x0e\x45valResultList\x12S\n\x07results\x18\x01 \x03(\x0b\x32\x39.cerbos.response.v1.PlaygroundEvaluateResponse.EvalResultR\x07results\x12\x36\n\x17\x65\x66\x66\x65\x63tive_derived_roles\x18\x02 \x03(\tR\x15\x65\x66\x66\x65\x63tiveDerivedRoles\x12N\n\x11validation_errors\x18\x03 \x03(\x0b\x32!.cerbos.schema.v1.ValidationErrorR\x10validationErrors\x12\x37\n\x07outputs\x18\x04 \x03(\x0b\x32\x1d.cerbos.engine.v1.OutputEntryR\x07outputs:#\x92\x41 \n\x1e\x32\x1cPlayground evaluate responseB\t\n\x07outcome\"\x9b\x04\n\x17PlaygroundProxyResponse\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12\x41\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32%.cerbos.response.v1.PlaygroundFailureH\x00R\x07\x66\x61ilure\x12\\\n\x12\x63heck_resource_set\x18\x03 \x01(\x0b\x32,.cerbos.response.v1.CheckResourceSetResponseH\x00R\x10\x63heckResourceSet\x12\x62\n\x14\x63heck_resource_batch\x18\x04 \x01(\x0b\x32..cerbos.response.v1.CheckResourceBatchResponseH\x00R\x12\x63heckResourceBatch\x12R\n\x0eplan_resources\x18\x05 \x01(\x0b\x32).cerbos.response.v1.PlanResourcesResponseH\x00R\rplanResources\x12U\n\x0f\x63heck_resources\x18\x06 \x01(\x0b\x32*.cerbos.response.v1.CheckResourcesResponseH\x00R\x0e\x63heckResources: \x92\x41\x1d\n\x1b\x32\x19Playground proxy responseB\t\n\x07outcome\"p\n\x19\x41\x64\x64OrUpdatePolicyResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x07success:!\x92\x41\x1e\n\x1c\x32\x1a\x41\x64\x64/update policy response\"\xe0\x01\n\x1bListAuditLogEntriesResponse\x12K\n\x10\x61\x63\x63\x65ss_log_entry\x18\x01 \x01(\x0b\x32\x1f.cerbos.audit.v1.AccessLogEntryH\x00R\x0e\x61\x63\x63\x65ssLogEntry\x12Q\n\x12\x64\x65\x63ision_log_entry\x18\x02 \x01(\x0b\x32!.cerbos.audit.v1.DecisionLogEntryH\x00R\x10\x64\x65\x63isionLogEntry:\x18\x92\x41\x15\n\x13\x32\x11\x41udit log stream.B\x07\n\x05\x65ntry\"\x82\x01\n\x12ServerInfoResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x16\n\x06\x63ommit\x18\x02 \x01(\tR\x06\x63ommit\x12\x1d\n\nbuild_date\x18\x03 \x01(\tR\tbuildDate:\x1b\x92\x41\x18\n\x16\x32\x14Server info response\"j\n\x14ListPoliciesResponse\x12\x1d\n\npolicy_ids\x18\x01 \x03(\tR\tpolicyIds:3\x92\x41\x30\n.2,List of policies stored in the Cerbos server\"e\n\x11GetPolicyResponse\x12\x34\n\x08policies\x18\x01 \x03(\x0b\x32\x18.cerbos.policy.v1.PolicyR\x08policies:\x1a\x92\x41\x17\n\x15\x32\x13Get policy response\"d\n\x15\x44isablePolicyResponse\x12+\n\x11\x64isabled_policies\x18\x01 \x01(\rR\x10\x64isabledPolicies:\x1e\x92\x41\x1b\n\x19\x32\x17\x44isable policy response\"`\n\x14\x45nablePolicyResponse\x12)\n\x10\x65nabled_policies\x18\x01 \x01(\rR\x0f\x65nabledPolicies:\x1d\x92\x41\x1a\n\x18\x32\x16\x45nable policy response\">\n\x19\x41\x64\x64OrUpdateSchemaResponse:!\x92\x41\x1e\n\x1c\x32\x1a\x41\x64\x64/update schema response\"U\n\x13ListSchemasResponse\x12\x1d\n\nschema_ids\x18\x01 \x03(\tR\tschemaIds:\x1f\x92\x41\x1c\n\x1a\x32\x18List schema ids response\"f\n\x11GetSchemaResponse\x12\x32\n\x07schemas\x18\x01 \x03(\x0b\x32\x18.cerbos.schema.v1.SchemaR\x07schemas:\x1d\x92\x41\x1a\n\x18\x32\x16Get schema(s) response\"a\n\x14\x44\x65leteSchemaResponse\x12\'\n\x0f\x64\x65leted_schemas\x18\x01 \x01(\rR\x0e\x64\x65letedSchemas: \x92\x41\x1d\n\x1b\x32\x19\x44\x65lete schema(s) response\"3\n\x13ReloadStoreResponse:\x1c\x92\x41\x19\n\x17\x32\x15Reload store responseBw\n\x1a\x64\x65v.cerbos.api.v1.responseZ@github.com/cerbos/cerbos/api/genpb/cerbos/response/v1;responsev1\xaa\x02\x16\x43\x65rbos.Api.V1.Responseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.response.v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032dev.cerbos.api.v1.responseZ@github.com/cerbos/cerbos/api/genpb/cerbos/response/v1;responsev1\252\002\026Cerbos.Api.V1.Response'
  _PLANRESOURCESRESPONSE_META.fields_by_name['filter_debug']._options = None
  _PLANRESOURCESRESPONSE_META.fields_by_name['filter_debug']._serialized_options = b'\222A725Filter textual representation for debugging purposes.'
  _PLANRESOURCESRESPONSE_META.fields_by_name['matched_scope']._options = None
  _PLANRESOURCESRESPONSE_META.fields_by_name['matched_scope']._serialized_options = b'\222AE21Policy scope that matched to produce this effect.J\020\"acme.corp.base\"'
  _PLANRESOURCESRESPONSE_META._options = None
  _PLANRESOURCESRESPONSE_META._serialized_options = b'\222A&\n$2\"Metadata about request evaluation.'
  _PLANRESOURCESRESPONSE.fields_by_name['request_id']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['request_id']._serialized_options = b'\222AM2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _PLANRESOURCESRESPONSE.fields_by_name['action']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['action']._serialized_options = b'\222A\0272\006ActionJ\r\"view:public\"'
  _PLANRESOURCESRESPONSE.fields_by_name['resource_kind']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['resource_kind']._serialized_options = b'\222Ab2\016Resource kind.J\016\"album:object\"\212\001?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$'
  _PLANRESOURCESRESPONSE.fields_by_name['policy_version']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['policy_version']._serialized_options = b'\222A 2\023The policy version.J\t\"default\"'
  _PLANRESOURCESRESPONSE.fields_by_name['filter']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['filter']._serialized_options = b'\222A\0102\006Filter'
  _PLANRESOURCESRESPONSE.fields_by_name['meta']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['meta']._serialized_options = b'\222A826Optional metadata about the request evaluation process'
  _PLANRESOURCESRESPONSE.fields_by_name['validation_errors']._options = None
  _PLANRESOURCESRESPONSE.fields_by_name['validation_errors']._serialized_options = b'\222A=2;List of validation errors (if schema validation is enabled)'
  _PLANRESOURCESRESPONSE._options = None
  _PLANRESOURCESRESPONSE._serialized_options = b'\222A9\n725Resources query plan response for a set of resources.'
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY._options = None
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP.fields_by_name['actions']._options = None
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP.fields_by_name['actions']._serialized_options = b'\222A&2$Mapping of each action to an effect.'
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP.fields_by_name['validation_errors']._options = None
  _CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP.fields_by_name['validation_errors']._serialized_options = b'\222A=2;List of validation errors (if schema validation is enabled)'
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA.fields_by_name['matched_policy']._options = None
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA.fields_by_name['matched_policy']._serialized_options = b'\222AE2+Policy that matched to produce this effect.J\026\"album:object:default\"'
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA.fields_by_name['matched_scope']._options = None
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA.fields_by_name['matched_scope']._serialized_options = b'\222AE21Policy scope that matched to produce this effect.J\020\"acme.corp.base\"'
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA._options = None
  _CHECKRESOURCESETRESPONSE_META_EFFECTMETA._serialized_options = b'\222A\027\n\0252\023Name of the action.'
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA_ACTIONSENTRY._options = None
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA.fields_by_name['actions']._options = None
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA.fields_by_name['actions']._serialized_options = b'\222A\275\0012OMetadata about the effect calculated for each action on this resource instance.Jj{\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}'
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA.fields_by_name['effective_derived_roles']._options = None
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA.fields_by_name['effective_derived_roles']._serialized_options = b'\222AH2;Derived roles that were effective during policy evaluation.J\t[\"owner\"]'
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA._options = None
  _CHECKRESOURCESETRESPONSE_META_ACTIONMETA._serialized_options = b'\222A8\n624Unique resource instance ID supplied in the request.'
  _CHECKRESOURCESETRESPONSE_META_RESOURCEINSTANCESENTRY._options = None
  _CHECKRESOURCESETRESPONSE_META_RESOURCEINSTANCESENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESETRESPONSE_META.fields_by_name['resource_instances']._options = None
  _CHECKRESOURCESETRESPONSE_META.fields_by_name['resource_instances']._serialized_options = b'\222A\321\0022\"Metadata about resource instances.J\252\002{\"XX125\": {\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}, \"effective_derived_roles\": [\"owner\"]}, \"XX225\": {\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}}}'
  _CHECKRESOURCESETRESPONSE_META._options = None
  _CHECKRESOURCESETRESPONSE_META._serialized_options = b'\222A&\n$2\"Metadata about request evaluation.'
  _CHECKRESOURCESETRESPONSE_RESOURCEINSTANCESENTRY._options = None
  _CHECKRESOURCESETRESPONSE_RESOURCEINSTANCESENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESETRESPONSE.fields_by_name['request_id']._options = None
  _CHECKRESOURCESETRESPONSE.fields_by_name['request_id']._serialized_options = b'\222AM2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCESETRESPONSE.fields_by_name['resource_instances']._options = None
  _CHECKRESOURCESETRESPONSE.fields_by_name['resource_instances']._serialized_options = b'\222A\342\0012KResults for each resource instance, keyed by the ID supplied in the requestJ\222\001{\"XX125\":{\"actions\":{\"view:*\":\"EFFECT_ALLOW\", \"comment\": \"EFFECT_ALLOW\"}}, \"XX225\":{\"actions\":{\"view:*\":\"EFFECT_DENY\", \"comment\": \"EFFECT_DENY\"}}}'
  _CHECKRESOURCESETRESPONSE.fields_by_name['meta']._options = None
  _CHECKRESOURCESETRESPONSE.fields_by_name['meta']._serialized_options = b'\222A826Optional metadata about the request evaluation process'
  _CHECKRESOURCESETRESPONSE._options = None
  _CHECKRESOURCESETRESPONSE._serialized_options = b'\222A6\n422Policy evaluation response for a set of resources.'
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY._options = None
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['resource_id']._options = None
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['resource_id']._serialized_options = b'\222A\0262\013Resource IDJ\007\"XX125\"'
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['actions']._options = None
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['actions']._serialized_options = b'\222A?2$Mapping of each action to an effect.J\027{\"view\":\"EFFECT_ALLOW\"}'
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['validation_errors']._options = None
  _CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP.fields_by_name['validation_errors']._serialized_options = b'\222A=2;List of validation errors (if schema validation is enabled)'
  _CHECKRESOURCEBATCHRESPONSE.fields_by_name['request_id']._options = None
  _CHECKRESOURCEBATCHRESPONSE.fields_by_name['request_id']._serialized_options = b'\222AM2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCEBATCHRESPONSE.fields_by_name['results']._options = None
  _CHECKRESOURCEBATCHRESPONSE.fields_by_name['results']._serialized_options = b'\222AV2\030Result for each resourceJ:[{\"resourceId\":\"XX125\",\"actions\":{\"view\":\"EFFECT_ALLOW\"}}]'
  _CHECKRESOURCEBATCHRESPONSE._options = None
  _CHECKRESOURCEBATCHRESPONSE._serialized_options = b'\222A8\n624Policy evaluation response for a batch of resources.'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['id']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['id']._serialized_options = b'\222A&2\033ID of the resource instanceJ\007\"XX125\"'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['kind']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['kind']._serialized_options = b'\222A|2)Name of the resource kind being accessed.J\r\"album:photo\"\212\001?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['policy_version']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['policy_version']._serialized_options = b'\222A\231\0012|The policy version to use to evaluate this request. If not specified, will default to the server-configured default version.J\t\"default\"\212\001\r^[[:word:]]*$'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['scope']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE.fields_by_name['scope']._serialized_options = b'\222A\276\0012}A dot-separated scope that describes the hierarchy this resource belongs to. This is used for determining policy inheritance.J\013\"acme.corp\"\212\001/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA.fields_by_name['matched_policy']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA.fields_by_name['matched_policy']._serialized_options = b'\222AE2+Policy that matched to produce this effect.J\026\"album:object:default\"'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA.fields_by_name['matched_scope']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA.fields_by_name['matched_scope']._serialized_options = b'\222AE21Policy scope that matched to produce this effect.J\020\"acme.corp.base\"'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA._serialized_options = b'\222A\027\n\0252\023Name of the action.'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_ACTIONSENTRY._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META.fields_by_name['actions']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META.fields_by_name['actions']._serialized_options = b'\222A\275\0012OMetadata about the effect calculated for each action on this resource instance.Jj{\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META.fields_by_name['effective_derived_roles']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META.fields_by_name['effective_derived_roles']._serialized_options = b'\222AH2;Derived roles that were effective during policy evaluation.J\t[\"owner\"]'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_META._serialized_options = b'\222A&\n$2\"Metadata about request evaluation.'
  _CHECKRESOURCESRESPONSE_RESULTENTRY_ACTIONSENTRY._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY_ACTIONSENTRY._serialized_options = b'8\001'
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['actions']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['actions']._serialized_options = b'\222A?2$Mapping of each action to an effect.J\027{\"view\":\"EFFECT_ALLOW\"}'
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['validation_errors']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['validation_errors']._serialized_options = b'\222A=2;List of validation errors (if schema validation is enabled)'
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['meta']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['meta']._serialized_options = b'\222A\302\0012 Metadata about policy evaluationJ\235\001{\"actions\": {\"view:*\":{\"matched_policy\": \"album:object:default\"},\"comment\":{\"matched_policy\": \"album:object:default\"}}, \"effective_derived_roles\": [\"owner\"]}'
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['outputs']._options = None
  _CHECKRESOURCESRESPONSE_RESULTENTRY.fields_by_name['outputs']._serialized_options = b'\222A\270\0012,Output for each rule with outputs configuredJ\207\001[{\"src\": \"resource.expense.v1/acme#rule-001\", \"val\": \"view_allowed:alice\"}, {\"src\": \"resource.expense.v1/acme#rule-002\", \"val\": \"foo\"}]'
  _CHECKRESOURCESRESPONSE.fields_by_name['request_id']._options = None
  _CHECKRESOURCESRESPONSE.fields_by_name['request_id']._serialized_options = b'\222AM2#Request ID provided in the request.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCESRESPONSE.fields_by_name['results']._options = None
  _CHECKRESOURCESRESPONSE.fields_by_name['results']._serialized_options = b'\222A\214\0012\030Result for each resourceJp[{\"resource\": {\"Id\":\"XX125\", \"kind\":\"album:object\"}, \"actions\":{\"view\":\"EFFECT_ALLOW\",\"comment\":\"EFFECT_DENY\"}}]'
  _CHECKRESOURCESRESPONSE._options = None
  _CHECKRESOURCESRESPONSE._serialized_options = b'\222A/\n-2+Response from the check resources API call.'
  _PLAYGROUNDFAILURE._options = None
  _PLAYGROUNDFAILURE._serialized_options = b'\222A\027\n\0252\023Playground response'
  _PLAYGROUNDVALIDATERESPONSE._options = None
  _PLAYGROUNDVALIDATERESPONSE._serialized_options = b'\222A \n\0362\034Playground validate response'
  _PLAYGROUNDTESTRESPONSE._options = None
  _PLAYGROUNDTESTRESPONSE._serialized_options = b'\222A\034\n\0322\030Playground test response'
  _PLAYGROUNDEVALUATERESPONSE_EVALRESULT.fields_by_name['effective_derived_roles']._options = None
  _PLAYGROUNDEVALUATERESPONSE_EVALRESULT.fields_by_name['effective_derived_roles']._serialized_options = b'\030\001'
  _PLAYGROUNDEVALUATERESPONSE_EVALRESULT.fields_by_name['validation_errors']._options = None
  _PLAYGROUNDEVALUATERESPONSE_EVALRESULT.fields_by_name['validation_errors']._serialized_options = b'\030\001'
  _PLAYGROUNDEVALUATERESPONSE._options = None
  _PLAYGROUNDEVALUATERESPONSE._serialized_options = b'\222A \n\0362\034Playground evaluate response'
  _PLAYGROUNDPROXYRESPONSE._options = None
  _PLAYGROUNDPROXYRESPONSE._serialized_options = b'\222A\035\n\0332\031Playground proxy response'
  _ADDORUPDATEPOLICYRESPONSE._options = None
  _ADDORUPDATEPOLICYRESPONSE._serialized_options = b'\222A\036\n\0342\032Add/update policy response'
  _LISTAUDITLOGENTRIESRESPONSE._options = None
  _LISTAUDITLOGENTRIESRESPONSE._serialized_options = b'\222A\025\n\0232\021Audit log stream.'
  _SERVERINFORESPONSE._options = None
  _SERVERINFORESPONSE._serialized_options = b'\222A\030\n\0262\024Server info response'
  _LISTPOLICIESRESPONSE._options = None
  _LISTPOLICIESRESPONSE._serialized_options = b'\222A0\n.2,List of policies stored in the Cerbos server'
  _GETPOLICYRESPONSE._options = None
  _GETPOLICYRESPONSE._serialized_options = b'\222A\027\n\0252\023Get policy response'
  _DISABLEPOLICYRESPONSE._options = None
  _DISABLEPOLICYRESPONSE._serialized_options = b'\222A\033\n\0312\027Disable policy response'
  _ENABLEPOLICYRESPONSE._options = None
  _ENABLEPOLICYRESPONSE._serialized_options = b'\222A\032\n\0302\026Enable policy response'
  _ADDORUPDATESCHEMARESPONSE._options = None
  _ADDORUPDATESCHEMARESPONSE._serialized_options = b'\222A\036\n\0342\032Add/update schema response'
  _LISTSCHEMASRESPONSE._options = None
  _LISTSCHEMASRESPONSE._serialized_options = b'\222A\034\n\0322\030List schema ids response'
  _GETSCHEMARESPONSE._options = None
  _GETSCHEMARESPONSE._serialized_options = b'\222A\032\n\0302\026Get schema(s) response'
  _DELETESCHEMARESPONSE._options = None
  _DELETESCHEMARESPONSE._serialized_options = b'\222A\035\n\0332\031Delete schema(s) response'
  _RELOADSTORERESPONSE._options = None
  _RELOADSTORERESPONSE._serialized_options = b'\222A\031\n\0272\025Reload store response'
  _globals['_PLANRESOURCESRESPONSE']._serialized_start=288
  _globals['_PLANRESOURCESRESPONSE']._serialized_end=1365
  _globals['_PLANRESOURCESRESPONSE_META']._serialized_start=1048
  _globals['_PLANRESOURCESRESPONSE_META']._serialized_end=1303
  _globals['_CHECKRESOURCESETRESPONSE']._serialized_start=1368
  _globals['_CHECKRESOURCESETRESPONSE']._serialized_end=4128
  _globals['_CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP']._serialized_start=1993
  _globals['_CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP']._serialized_end=2388
  _globals['_CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY']._serialized_start=2304
  _globals['_CHECKRESOURCESETRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY']._serialized_end=2388
  _globals['_CHECKRESOURCESETRESPONSE_META']._serialized_start=2391
  _globals['_CHECKRESOURCESETRESPONSE_META']._serialized_end=3936
  _globals['_CHECKRESOURCESETRESPONSE_META_EFFECTMETA']._serialized_start=2866
  _globals['_CHECKRESOURCESETRESPONSE_META_EFFECTMETA']._serialized_end=3130
  _globals['_CHECKRESOURCESETRESPONSE_META_ACTIONMETA']._serialized_start=3133
  _globals['_CHECKRESOURCESETRESPONSE_META_ACTIONMETA']._serialized_end=3760
  _globals['_CHECKRESOURCESETRESPONSE_META_ACTIONMETA_ACTIONSENTRY']._serialized_start=3579
  _globals['_CHECKRESOURCESETRESPONSE_META_ACTIONMETA_ACTIONSENTRY']._serialized_end=3699
  _globals['_CHECKRESOURCESETRESPONSE_META_RESOURCEINSTANCESENTRY']._serialized_start=3763
  _globals['_CHECKRESOURCESETRESPONSE_META_RESOURCEINSTANCESENTRY']._serialized_end=3893
  _globals['_CHECKRESOURCESETRESPONSE_RESOURCEINSTANCESENTRY']._serialized_start=3939
  _globals['_CHECKRESOURCESETRESPONSE_RESOURCEINSTANCESENTRY']._serialized_end=4069
  _globals['_CHECKRESOURCEBATCHRESPONSE']._serialized_start=4131
  _globals['_CHECKRESOURCEBATCHRESPONSE']._serialized_end=5000
  _globals['_CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP']._serialized_start=4457
  _globals['_CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP']._serialized_end=4939
  _globals['_CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY']._serialized_start=2304
  _globals['_CHECKRESOURCEBATCHRESPONSE_ACTIONEFFECTMAP_ACTIONSENTRY']._serialized_end=2388
  _globals['_CHECKRESOURCESRESPONSE']._serialized_start=5003
  _globals['_CHECKRESOURCESRESPONSE']._serialized_end=7985
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY']._serialized_start=5373
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY']._serialized_end=7933
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE']._serialized_start=6325
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_RESOURCE']._serialized_end=6964
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META']._serialized_start=6967
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META']._serialized_end=7847
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA']._serialized_start=2866
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META_EFFECTMETA']._serialized_end=3130
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META_ACTIONSENTRY']._serialized_start=7674
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_META_ACTIONSENTRY']._serialized_end=7804
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_ACTIONSENTRY']._serialized_start=2304
  _globals['_CHECKRESOURCESRESPONSE_RESULTENTRY_ACTIONSENTRY']._serialized_end=2388
  _globals['_PLAYGROUNDFAILURE']._serialized_start=7988
  _globals['_PLAYGROUNDFAILURE']._serialized_end=8155
  _globals['_PLAYGROUNDFAILURE_ERROR']._serialized_start=8078
  _globals['_PLAYGROUNDFAILURE_ERROR']._serialized_end=8127
  _globals['_PLAYGROUNDVALIDATERESPONSE']._serialized_start=8158
  _globals['_PLAYGROUNDVALIDATERESPONSE']._serialized_end=8390
  _globals['_PLAYGROUNDTESTRESPONSE']._serialized_start=8393
  _globals['_PLAYGROUNDTESTRESPONSE']._serialized_end=8721
  _globals['_PLAYGROUNDTESTRESPONSE_TESTRESULTS']._serialized_start=8607
  _globals['_PLAYGROUNDTESTRESPONSE_TESTRESULTS']._serialized_end=8677
  _globals['_PLAYGROUNDEVALUATERESPONSE']._serialized_start=8724
  _globals['_PLAYGROUNDEVALUATERESPONSE']._serialized_end=9549
  _globals['_PLAYGROUNDEVALUATERESPONSE_EVALRESULT']._serialized_start=8950
  _globals['_PLAYGROUNDEVALUATERESPONSE_EVALRESULT']._serialized_end=9204
  _globals['_PLAYGROUNDEVALUATERESPONSE_EVALRESULTLIST']._serialized_start=9207
  _globals['_PLAYGROUNDEVALUATERESPONSE_EVALRESULTLIST']._serialized_end=9501
  _globals['_PLAYGROUNDPROXYRESPONSE']._serialized_start=9552
  _globals['_PLAYGROUNDPROXYRESPONSE']._serialized_end=10091
  _globals['_ADDORUPDATEPOLICYRESPONSE']._serialized_start=10093
  _globals['_ADDORUPDATEPOLICYRESPONSE']._serialized_end=10205
  _globals['_LISTAUDITLOGENTRIESRESPONSE']._serialized_start=10208
  _globals['_LISTAUDITLOGENTRIESRESPONSE']._serialized_end=10432
  _globals['_SERVERINFORESPONSE']._serialized_start=10435
  _globals['_SERVERINFORESPONSE']._serialized_end=10565
  _globals['_LISTPOLICIESRESPONSE']._serialized_start=10567
  _globals['_LISTPOLICIESRESPONSE']._serialized_end=10673
  _globals['_GETPOLICYRESPONSE']._serialized_start=10675
  _globals['_GETPOLICYRESPONSE']._serialized_end=10776
  _globals['_DISABLEPOLICYRESPONSE']._serialized_start=10778
  _globals['_DISABLEPOLICYRESPONSE']._serialized_end=10878
  _globals['_ENABLEPOLICYRESPONSE']._serialized_start=10880
  _globals['_ENABLEPOLICYRESPONSE']._serialized_end=10976
  _globals['_ADDORUPDATESCHEMARESPONSE']._serialized_start=10978
  _globals['_ADDORUPDATESCHEMARESPONSE']._serialized_end=11040
  _globals['_LISTSCHEMASRESPONSE']._serialized_start=11042
  _globals['_LISTSCHEMASRESPONSE']._serialized_end=11127
  _globals['_GETSCHEMARESPONSE']._serialized_start=11129
  _globals['_GETSCHEMARESPONSE']._serialized_end=11231
  _globals['_DELETESCHEMARESPONSE']._serialized_start=11233
  _globals['_DELETESCHEMARESPONSE']._serialized_end=11330
  _globals['_RELOADSTORERESPONSE']._serialized_start=11332
  _globals['_RELOADSTORERESPONSE']._serialized_end=11383
# @@protoc_insertion_point(module_scope)
