# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/svc/v1/svc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cerbos.request.v1 import request_pb2 as cerbos_dot_request_dot_v1_dot_request__pb2
from cerbos.response.v1 import response_pb2 as cerbos_dot_response_dot_v1_dot_response__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63\x65rbos/svc/v1/svc.proto\x12\rcerbos.svc.v1\x1a\x1f\x63\x65rbos/request/v1/request.proto\x1a!cerbos/response/v1/response.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xd6\n\n\rCerbosService\x12\xa7\x02\n\x10\x43heckResourceSet\x12*.cerbos.request.v1.CheckResourceSetRequest\x1a,.cerbos.response.v1.CheckResourceSetResponse\"\xb8\x01\x92\x41\x9f\x01\x12\x05\x43heck\x1a\x93\x01[Deprecated: Use CheckResources API instead] Check whether a principal has permissions to perform the given actions on a set of resource instances.X\x01\x82\xd3\xe4\x93\x02\x0f\"\n/api/check:\x01*\x12\xb6\x02\n\x12\x43heckResourceBatch\x12,.cerbos.request.v1.CheckResourceBatchRequest\x1a..cerbos.response.v1.CheckResourceBatchResponse\"\xc1\x01\x92\x41\x99\x01\x12\x14\x43heck resource batch\x1a\x7f[Deprecated: Use CheckResources API instead] Check a principal\'s permissions to a batch of heterogeneous resources and actions.X\x01\x82\xd3\xe4\x93\x02\x1e\"\x19/api/check_resource_batch:\x01*\x12\xf0\x01\n\x0e\x43heckResources\x12(.cerbos.request.v1.CheckResourcesRequest\x1a*.cerbos.response.v1.CheckResourcesResponse\"\x87\x01\x92\x41\x65\x12\x0f\x43heck resources\x1aRCheck a principal\'s permissions to a batch of heterogeneous resources and actions.\x82\xd3\xe4\x93\x02\x19\"\x14/api/check/resources:\x01*\x12\xc5\x01\n\nServerInfo\x12$.cerbos.request.v1.ServerInfoRequest\x1a&.cerbos.response.v1.ServerInfoResponse\"i\x92\x41N\x12\x16Get server information\x1a\x34Get information about the server e.g. server version\x82\xd3\xe4\x93\x02\x12\x12\x10/api/server_info\x12\x83\x02\n\rPlanResources\x12\'.cerbos.request.v1.PlanResourcesRequest\x1a).cerbos.response.v1.PlanResourcesResponse\"\x9d\x01\x92\x41|\x12\x0ePlan resources\x1ajProduce a query plan with conditions that must be satisfied for accessing a set of instances of a resource\x82\xd3\xe4\x93\x02\x18\"\x13/api/plan/resources:\x01*\x1a!\x92\x41\x1e\x12\x1c\x43\x65rbos Policy Decision Point2\xc5\x0f\n\x12\x43\x65rbosAdminService\x12\xc9\x01\n\x11\x41\x64\x64OrUpdatePolicy\x12+.cerbos.request.v1.AddOrUpdatePolicyRequest\x1a-.cerbos.response.v1.AddOrUpdatePolicyResponse\"X\x92\x41)\x12\x16\x41\x64\x64 or update policiesb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02&\"\r/admin/policy:\x01*Z\x12\x1a\r/admin/policy:\x01*\x12\x9c\x01\n\x0cListPolicies\x12&.cerbos.request.v1.ListPoliciesRequest\x1a(.cerbos.response.v1.ListPoliciesResponse\":\x92\x41 \x12\rList policiesb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x11\x12\x0f/admin/policies\x12\x8e\x01\n\tGetPolicy\x12#.cerbos.request.v1.GetPolicyRequest\x1a%.cerbos.response.v1.GetPolicyResponse\"5\x92\x41\x1d\x12\nGet policyb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x0f\x12\r/admin/policy\x12\xd3\x01\n\rDisablePolicy\x12\'.cerbos.request.v1.DisablePolicyRequest\x1a).cerbos.response.v1.DisablePolicyResponse\"n\x92\x41!\x12\x0e\x44isable policyb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x44\"\x15/admin/policy/disableZ\x1a\x1a\x15/admin/policy/disable:\x01*Z\x0f*\r/admin/policy\x12\xbc\x01\n\x0c\x45nablePolicy\x12&.cerbos.request.v1.EnablePolicyRequest\x1a(.cerbos.response.v1.EnablePolicyResponse\"Z\x92\x41 \x12\rEnable policyb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x31\"\x14/admin/policy/enableZ\x19\x1a\x14/admin/policy/enable:\x01*\x12\xc8\x01\n\x13ListAuditLogEntries\x12-.cerbos.request.v1.ListAuditLogEntriesRequest\x1a/.cerbos.response.v1.ListAuditLogEntriesResponse\"O\x92\x41)\x12\x16List audit log entriesb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x1d\x12\x1b/admin/auditlog/list/{kind}0\x01\x12\xc7\x01\n\x11\x41\x64\x64OrUpdateSchema\x12+.cerbos.request.v1.AddOrUpdateSchemaRequest\x1a-.cerbos.response.v1.AddOrUpdateSchemaResponse\"V\x92\x41\'\x12\x14\x41\x64\x64 or update schemab\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02&\"\r/admin/schema:\x01*Z\x12\x1a\r/admin/schema:\x01*\x12\x97\x01\n\x0bListSchemas\x12%.cerbos.request.v1.ListSchemasRequest\x1a\'.cerbos.response.v1.ListSchemasResponse\"8\x92\x41\x1f\x12\x0cList schemasb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x10\x12\x0e/admin/schemas\x12\x8e\x01\n\tGetSchema\x12#.cerbos.request.v1.GetSchemaRequest\x1a%.cerbos.response.v1.GetSchemaResponse\"5\x92\x41\x1d\x12\nGet schemab\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x0f\x12\r/admin/schema\x12\x9a\x01\n\x0c\x44\x65leteSchema\x12&.cerbos.request.v1.DeleteSchemaRequest\x1a(.cerbos.response.v1.DeleteSchemaResponse\"8\x92\x41 \x12\rDelete schemab\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x0f*\r/admin/schema\x12\x9c\x01\n\x0bReloadStore\x12%.cerbos.request.v1.ReloadStoreRequest\x1a\'.cerbos.response.v1.ReloadStoreResponse\"=\x92\x41\x1f\x12\x0cReload storeb\x0f\n\r\n\tBasicAuth\x12\x00\x82\xd3\xe4\x93\x02\x15\x12\x13/admin/store/reload\x1a\"\x92\x41\x1f\x12\x1d\x43\x65rbos administration service2\xf7\x04\n\x17\x43\x65rbosPlaygroundService\x12\x97\x01\n\x12PlaygroundValidate\x12,.cerbos.request.v1.PlaygroundValidateRequest\x1a..cerbos.response.v1.PlaygroundValidateResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/api/playground/validate:\x01*\x12\x87\x01\n\x0ePlaygroundTest\x12(.cerbos.request.v1.PlaygroundTestRequest\x1a*.cerbos.response.v1.PlaygroundTestResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/playground/test:\x01*\x12\x97\x01\n\x12PlaygroundEvaluate\x12,.cerbos.request.v1.PlaygroundEvaluateRequest\x1a..cerbos.response.v1.PlaygroundEvaluateResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/api/playground/evaluate:\x01*\x12\x8b\x01\n\x0fPlaygroundProxy\x12).cerbos.request.v1.PlaygroundProxyRequest\x1a+.cerbos.response.v1.PlaygroundProxyResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/playground/proxy:\x01*\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xe1\x01\n\x15\x64\x65v.cerbos.api.v1.svcZ6github.com/cerbos/cerbos/api/genpb/cerbos/svc/v1;svcv1\xaa\x02\x11\x43\x65rbos.Api.V1.Svc\x92\x41{\x12?\n\x06\x43\x65rbos\"-\n\x06\x43\x65rbos\x12\x12https://cerbos.dev\x1a\x0finfo@cerbos.dev2\x06latest*\x01\x02\x32\x10\x61pplication/json:\x10\x61pplication/jsonZ\x11\n\x0f\n\tBasicAuth\x12\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.svc.v1.svc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025dev.cerbos.api.v1.svcZ6github.com/cerbos/cerbos/api/genpb/cerbos/svc/v1;svcv1\252\002\021Cerbos.Api.V1.Svc\222A{\022?\n\006Cerbos\"-\n\006Cerbos\022\022https://cerbos.dev\032\017info@cerbos.dev2\006latest*\001\0022\020application/json:\020application/jsonZ\021\n\017\n\tBasicAuth\022\002\010\001'
  _CERBOSSERVICE._options = None
  _CERBOSSERVICE._serialized_options = b'\222A\036\022\034Cerbos Policy Decision Point'
  _CERBOSSERVICE.methods_by_name['CheckResourceSet']._options = None
  _CERBOSSERVICE.methods_by_name['CheckResourceSet']._serialized_options = b'\222A\237\001\022\005Check\032\223\001[Deprecated: Use CheckResources API instead] Check whether a principal has permissions to perform the given actions on a set of resource instances.X\001\202\323\344\223\002\017\"\n/api/check:\001*'
  _CERBOSSERVICE.methods_by_name['CheckResourceBatch']._options = None
  _CERBOSSERVICE.methods_by_name['CheckResourceBatch']._serialized_options = b'\222A\231\001\022\024Check resource batch\032\177[Deprecated: Use CheckResources API instead] Check a principal\'s permissions to a batch of heterogeneous resources and actions.X\001\202\323\344\223\002\036\"\031/api/check_resource_batch:\001*'
  _CERBOSSERVICE.methods_by_name['CheckResources']._options = None
  _CERBOSSERVICE.methods_by_name['CheckResources']._serialized_options = b'\222Ae\022\017Check resources\032RCheck a principal\'s permissions to a batch of heterogeneous resources and actions.\202\323\344\223\002\031\"\024/api/check/resources:\001*'
  _CERBOSSERVICE.methods_by_name['ServerInfo']._options = None
  _CERBOSSERVICE.methods_by_name['ServerInfo']._serialized_options = b'\222AN\022\026Get server information\0324Get information about the server e.g. server version\202\323\344\223\002\022\022\020/api/server_info'
  _CERBOSSERVICE.methods_by_name['PlanResources']._options = None
  _CERBOSSERVICE.methods_by_name['PlanResources']._serialized_options = b'\222A|\022\016Plan resources\032jProduce a query plan with conditions that must be satisfied for accessing a set of instances of a resource\202\323\344\223\002\030\"\023/api/plan/resources:\001*'
  _CERBOSADMINSERVICE._options = None
  _CERBOSADMINSERVICE._serialized_options = b'\222A\037\022\035Cerbos administration service'
  _CERBOSADMINSERVICE.methods_by_name['AddOrUpdatePolicy']._options = None
  _CERBOSADMINSERVICE.methods_by_name['AddOrUpdatePolicy']._serialized_options = b'\222A)\022\026Add or update policiesb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002&\"\r/admin/policy:\001*Z\022\032\r/admin/policy:\001*'
  _CERBOSADMINSERVICE.methods_by_name['ListPolicies']._options = None
  _CERBOSADMINSERVICE.methods_by_name['ListPolicies']._serialized_options = b'\222A \022\rList policiesb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\021\022\017/admin/policies'
  _CERBOSADMINSERVICE.methods_by_name['GetPolicy']._options = None
  _CERBOSADMINSERVICE.methods_by_name['GetPolicy']._serialized_options = b'\222A\035\022\nGet policyb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\017\022\r/admin/policy'
  _CERBOSADMINSERVICE.methods_by_name['DisablePolicy']._options = None
  _CERBOSADMINSERVICE.methods_by_name['DisablePolicy']._serialized_options = b'\222A!\022\016Disable policyb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002D\"\025/admin/policy/disableZ\032\032\025/admin/policy/disable:\001*Z\017*\r/admin/policy'
  _CERBOSADMINSERVICE.methods_by_name['EnablePolicy']._options = None
  _CERBOSADMINSERVICE.methods_by_name['EnablePolicy']._serialized_options = b'\222A \022\rEnable policyb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\0021\"\024/admin/policy/enableZ\031\032\024/admin/policy/enable:\001*'
  _CERBOSADMINSERVICE.methods_by_name['ListAuditLogEntries']._options = None
  _CERBOSADMINSERVICE.methods_by_name['ListAuditLogEntries']._serialized_options = b'\222A)\022\026List audit log entriesb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\035\022\033/admin/auditlog/list/{kind}'
  _CERBOSADMINSERVICE.methods_by_name['AddOrUpdateSchema']._options = None
  _CERBOSADMINSERVICE.methods_by_name['AddOrUpdateSchema']._serialized_options = b'\222A\'\022\024Add or update schemab\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002&\"\r/admin/schema:\001*Z\022\032\r/admin/schema:\001*'
  _CERBOSADMINSERVICE.methods_by_name['ListSchemas']._options = None
  _CERBOSADMINSERVICE.methods_by_name['ListSchemas']._serialized_options = b'\222A\037\022\014List schemasb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\020\022\016/admin/schemas'
  _CERBOSADMINSERVICE.methods_by_name['GetSchema']._options = None
  _CERBOSADMINSERVICE.methods_by_name['GetSchema']._serialized_options = b'\222A\035\022\nGet schemab\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\017\022\r/admin/schema'
  _CERBOSADMINSERVICE.methods_by_name['DeleteSchema']._options = None
  _CERBOSADMINSERVICE.methods_by_name['DeleteSchema']._serialized_options = b'\222A \022\rDelete schemab\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\017*\r/admin/schema'
  _CERBOSADMINSERVICE.methods_by_name['ReloadStore']._options = None
  _CERBOSADMINSERVICE.methods_by_name['ReloadStore']._serialized_options = b'\222A\037\022\014Reload storeb\017\n\r\n\tBasicAuth\022\000\202\323\344\223\002\025\022\023/admin/store/reload'
  _CERBOSPLAYGROUNDSERVICE._options = None
  _CERBOSPLAYGROUNDSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundValidate']._options = None
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundValidate']._serialized_options = b'\202\323\344\223\002\035\"\030/api/playground/validate:\001*'
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundTest']._options = None
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundTest']._serialized_options = b'\202\323\344\223\002\031\"\024/api/playground/test:\001*'
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundEvaluate']._options = None
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundEvaluate']._serialized_options = b'\202\323\344\223\002\035\"\030/api/playground/evaluate:\001*'
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundProxy']._options = None
  _CERBOSPLAYGROUNDSERVICE.methods_by_name['PlaygroundProxy']._serialized_options = b'\202\323\344\223\002\032\"\025/api/playground/proxy:\001*'
  _globals['_CERBOSSERVICE']._serialized_start=218
  _globals['_CERBOSSERVICE']._serialized_end=1584
  _globals['_CERBOSADMINSERVICE']._serialized_start=1587
  _globals['_CERBOSADMINSERVICE']._serialized_end=3576
  _globals['_CERBOSPLAYGROUNDSERVICE']._serialized_start=3579
  _globals['_CERBOSPLAYGROUNDSERVICE']._serialized_end=4210
# @@protoc_insertion_point(module_scope)
