# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cerbos/request/v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cerbos.engine.v1 import engine_pb2 as cerbos_dot_engine_dot_v1_dot_engine__pb2
from cerbos.policy.v1 import policy_pb2 as cerbos_dot_policy_dot_v1_dot_policy__pb2
from cerbos.schema.v1 import schema_pb2 as cerbos_dot_schema_dot_v1_dot_schema__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63\x65rbos/request/v1/request.proto\x12\x11\x63\x65rbos.request.v1\x1a\x1d\x63\x65rbos/engine/v1/engine.proto\x1a\x1d\x63\x65rbos/policy/v1/policy.proto\x1a\x1d\x63\x65rbos/schema/v1/schema.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x17validate/validate.proto\"\x87\x05\n\x14PlanResourcesRequest\x12\x96\x01\n\nrequest_id\x18\x01 \x01(\tBw\x92\x41t2JOptional application-specific ID useful for correlating logs for analysis.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12i\n\x06\x61\x63tion\x18\x02 \x01(\tBQ\x92\x41\x43\x32\x32\x41\x63tion to be applied to each resource in the list.J\r\"view:public\"\xe2\x41\x01\x02\xfa\x42\x04r\x02\x10\x01R\x06\x61\x63tion\x12G\n\tprincipal\x18\x03 \x01(\x0b\x32\x1b.cerbos.engine.v1.PrincipalB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\tprincipal\x12W\n\x08resource\x18\x04 \x01(\x0b\x32-.cerbos.engine.v1.PlanResourcesInput.ResourceB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resource\x12;\n\x08\x61ux_data\x18\x05 \x01(\x0b\x32\x1a.cerbos.request.v1.AuxDataB\x04\xe2\x41\x01\x01R\x07\x61uxData\x12\x63\n\x0cinclude_meta\x18\x06 \x01(\x08\x42@\x92\x41=2;Opt to receive request processing metadata in the response.R\x0bincludeMeta:\'\x92\x41$\n\"2 PDP Resources Query Plan Request\"\x8b\x05\n\x17\x43heckResourceSetRequest\x12\x96\x01\n\nrequest_id\x18\x01 \x01(\tBw\x92\x41t2JOptional application-specific ID useful for correlating logs for analysis.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12\x8d\x01\n\x07\x61\x63tions\x18\x02 \x03(\tBs\x92\x41\\28List of actions being performed on the set of resources.J\x1a[\"view:public\", \"comment\"]\xa8\x01\x01\xb0\x01\x01\xe2\x41\x01\x02\xfa\x42\r\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01R\x07\x61\x63tions\x12G\n\tprincipal\x18\x03 \x01(\x0b\x32\x1b.cerbos.engine.v1.PrincipalB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\tprincipal\x12H\n\x08resource\x18\x04 \x01(\x0b\x32\x1e.cerbos.request.v1.ResourceSetB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resource\x12\x63\n\x0cinclude_meta\x18\x05 \x01(\x08\x42@\x92\x41=2;Opt to receive request processing metadata in the response.R\x0bincludeMeta\x12;\n\x08\x61ux_data\x18\x06 \x01(\x0b\x32\x1a.cerbos.request.v1.AuxDataB\x04\xe2\x41\x01\x01R\x07\x61uxData:\x12\x92\x41\x0f\n\r2\x0bPDP Request\"\xb3\t\n\x0bResourceSet\x12\xc8\x01\n\x04kind\x18\x01 \x01(\tB\xb3\x01\x92\x41\x62\x32\x0eResource kind.J\x0e\"album:object\"\x8a\x01?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$\xe2\x41\x01\x02\xfa\x42GrE\x10\x01\x32\x41^[[:alpha:]][[:word:]\\@\\.\\-/]*(\\:[[:alpha:]][[:word:]\\@\\.\\-/]*)*$R\x04kind\x12\xdd\x01\n\x0epolicy_version\x18\x02 \x01(\tB\xb5\x01\x92\x41\x99\x01\x32|The policy version to use to evaluate this request. If not specified, will default to the server-configured default version.J\t\"default\"\x8a\x01\r^[[:word:]]*$\xe2\x41\x01\x01\xfa\x42\x11r\x0f\x32\r^[[:word:]]*$R\rpolicyVersion\x12\xec\x02\n\tinstances\x18\x03 \x03(\x0b\x32-.cerbos.request.v1.ResourceSet.InstancesEntryB\x9e\x02\x92\x41\x8c\x02\x32mSet of resource instances to check. Each instance must be keyed by an application-specific unique identifier.J\x97\x01{\"XX125\":{\"attr\":{\"owner\":\"bugs_bunny\", \"public\": false, \"flagged\": false}}, \"XX225\":{\"attr\":{\"owner\":\"daffy_duck\", \"public\": true, \"flagged\": false}}}\xc8\x01\x01\xe2\x41\x01\x02\xfa\x42\x07\x9a\x01\x04\x08\x01\x18\x01R\tinstances\x12\x87\x02\n\x05scope\x18\x04 \x01(\tB\xf0\x01\x92\x41\xb2\x01\x32~A dot-separated scope that describes the hierarchy these resources belong to. This is used for determining policy inheritance.\x8a\x01/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$\xe2\x41\x01\x01\xfa\x42\x33r12/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$R\x05scope\x1a^\n\x0eInstancesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32 .cerbos.request.v1.AttributesMapR\x05value:\x02\x38\x01: \x92\x41\x1d\n\x1b\x32\x19Set of resources to check\"\xc9\x02\n\rAttributesMap\x12\xb1\x01\n\x04\x61ttr\x18\x01 \x03(\x0b\x32*.cerbos.request.v1.AttributesMap.AttrEntryBq\x92\x41\x66\x32\x64Key-value pairs of contextual data about this instance that should be used during policy evaluation.\xfa\x42\x05\x9a\x01\x02\x18\x01R\x04\x61ttr\x1aO\n\tAttrEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01:3\x92\x41\x30\n.2,Unique identifier for the resource instance.\"\xe5\x06\n\x19\x43heckResourceBatchRequest\x12\x96\x01\n\nrequest_id\x18\x01 \x01(\tBw\x92\x41t2JOptional application-specific ID useful for correlating logs for analysis.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12G\n\tprincipal\x18\x02 \x01(\x0b\x32\x1b.cerbos.engine.v1.PrincipalB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\tprincipal\x12\xbd\x02\n\tresources\x18\x03 \x03(\x0b\x32\x37.cerbos.request.v1.CheckResourceBatchRequest.BatchEntryB\xe5\x01\x92\x41\xd5\x01\x32\x1eList of resources and actions.J\xac\x01[{\"actions\":[\"view\",\"comment\"], \"resource\":{\"kind\":\"album:object\",\"policyVersion\":\"default\",\"id\":\"XX125\",\"attr\":{\"owner\":\"bugs_bunny\", \"public\": false, \"flagged\": false}}}]\xa8\x01\x01\xb0\x01\x01\xe2\x41\x01\x02\xfa\x42\x05\x92\x01\x02\x08\x01R\tresources\x12\x35\n\x08\x61ux_data\x18\x04 \x01(\x0b\x32\x1a.cerbos.request.v1.AuxDataR\x07\x61uxData\x1a\xda\x01\n\nBatchEntry\x12\x85\x01\n\x07\x61\x63tions\x18\x01 \x03(\tBk\x92\x41T20List of actions being performed on the resource.J\x1a[\"view:public\", \"comment\"]\xa8\x01\x01\xb0\x01\x01\xe2\x41\x01\x02\xfa\x42\r\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01R\x07\x61\x63tions\x12\x44\n\x08resource\x18\x02 \x01(\x0b\x32\x1a.cerbos.engine.v1.ResourceB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resource:\x12\x92\x41\x0f\n\r2\x0bPDP Request\"\xc9\x07\n\x15\x43heckResourcesRequest\x12\x96\x01\n\nrequest_id\x18\x01 \x01(\tBw\x92\x41t2JOptional application-specific ID useful for correlating logs for analysis.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"R\trequestId\x12X\n\x0cinclude_meta\x18\x02 \x01(\x08\x42\x35\x92\x41\x32\x32\x30\x41\x64\x64 request processing metadata to the response.R\x0bincludeMeta\x12G\n\tprincipal\x18\x03 \x01(\x0b\x32\x1b.cerbos.engine.v1.PrincipalB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\tprincipal\x12\xbc\x02\n\tresources\x18\x04 \x03(\x0b\x32\x36.cerbos.request.v1.CheckResourcesRequest.ResourceEntryB\xe5\x01\x92\x41\xd5\x01\x32\x1eList of resources and actions.J\xac\x01[{\"actions\":[\"view\",\"comment\"], \"resource\":{\"kind\":\"album:object\",\"policyVersion\":\"default\",\"id\":\"XX125\",\"attr\":{\"owner\":\"bugs_bunny\", \"public\": false, \"flagged\": false}}}]\xa8\x01\x01\xb0\x01\x01\xe2\x41\x01\x02\xfa\x42\x05\x92\x01\x02\x08\x01R\tresources\x12\x35\n\x08\x61ux_data\x18\x05 \x01(\x0b\x32\x1a.cerbos.request.v1.AuxDataR\x07\x61uxData\x1a\xdd\x01\n\rResourceEntry\x12\x85\x01\n\x07\x61\x63tions\x18\x01 \x03(\tBk\x92\x41T20List of actions being performed on the resource.J\x1a[\"view:public\", \"comment\"]\xa8\x01\x01\xb0\x01\x01\xe2\x41\x01\x02\xfa\x42\r\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01R\x07\x61\x63tions\x12\x44\n\x08resource\x18\x02 \x01(\x0b\x32\x1a.cerbos.engine.v1.ResourceB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resource:\x1e\x92\x41\x1b\n\x19\x32\x17\x43heck resources request\"\xc6\x06\n\x07\x41uxData\x12\x30\n\x03jwt\x18\x01 \x01(\x0b\x32\x1e.cerbos.request.v1.AuxData.JWTR\x03jwt\x1a\xc4\x05\n\x03JWT\x12\x91\x04\n\x05token\x18\x01 \x01(\tB\xfa\x03\x92\x41\xeb\x03\x32\x1dJWT from the original requestJ\xc9\x03\"eyJhbGciOiJFUzM4NCIsImtpZCI6IjE5TGZaYXRFZGc4M1lOYzVyMjNndU1KcXJuND0iLCJ0eXAiOiJKV1QifQ.eyJhdWQiOlsiY2VyYm9zLWp3dC10ZXN0cyJdLCJjdXN0b21BcnJheSI6WyJBIiwiQiIsIkMiXSwiY3VzdG9tSW50Ijo0MiwiY3VzdG9tTWFwIjp7IkEiOiJBQSIsIkIiOiJCQiIsIkMiOiJDQyJ9LCJjdXN0b21TdHJpbmciOiJmb29iYXIiLCJleHAiOjE5NDk5MzQwMzksImlzcyI6ImNlcmJvcy10ZXN0LXN1aXRlIn0.WN_tOScSpd_EI-P5EI1YlagxEgExSfBjAtcrgcF6lyWj1lGpR_GKx9goZEp2p_t5AVWXN_bjz_sMUmJdJa4cVd55Qm1miR-FKu6oNRHnSEWdMFmnArwPw-YDJWfylLFX\"\xe2\x41\x01\x02\xfa\x42\x04r\x02\x10\x01R\x05token\x12\x82\x01\n\nkey_set_id\x18\x02 \x01(\tBd\x92\x41\x61\x32RKey ID to use when decoding the token (defined in the Cerbos server configuration)J\x0b\"my-keyset\"R\x08keySetId:$\x92\x41!\n\x1f\x32\x1dJWT from the original request:B\x92\x41?\n=2;Structured auxiliary data useful for evaluating the request\"]\n\x04\x46ile\x12(\n\tfile_name\x18\x01 \x01(\tB\x0b\xe2\x41\x01\x02\xfa\x42\x04r\x02\x10\x01R\x08\x66ileName\x12+\n\x08\x63ontents\x18\x02 \x01(\x0c\x42\x0f\xe2\x41\x01\x02\xfa\x42\x08z\x06\x10\x01\x18\x80\x80@R\x08\x63ontents\"\xbc\x01\n\x19PlaygroundValidateRequest\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12V\n\x05\x66iles\x18\x02 \x03(\x0b\x32\x17.cerbos.request.v1.FileB\'\x92\x41\x16\x32\x0eList of files.\xa0\x01\x1e\xa8\x01\x01\xe2\x41\x01\x02\xfa\x42\x07\x92\x01\x04\x08\x01\x10\x1eR\x05\x66iles:\"\x92\x41\x1f\n\x1d\x32\x1bPlayground validate request\"\xb4\x01\n\x15PlaygroundTestRequest\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12V\n\x05\x66iles\x18\x02 \x03(\x0b\x32\x17.cerbos.request.v1.FileB\'\x92\x41\x16\x32\x0eList of files.\xa0\x01\x1e\xa8\x01\x01\xe2\x41\x01\x02\xfa\x42\x07\x92\x01\x04\x08\x01\x10\x1eR\x05\x66iles:\x1e\x92\x41\x1b\n\x19\x32\x17Playground test request\"\xf2\x03\n\x19PlaygroundEvaluateRequest\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12V\n\x05\x66iles\x18\x02 \x03(\x0b\x32\x17.cerbos.request.v1.FileB\'\x92\x41\x16\x32\x0eList of files.\xa0\x01\x1e\xa8\x01\x01\xe2\x41\x01\x02\xfa\x42\x07\x92\x01\x04\x08\x01\x10\x1eR\x05\x66iles\x12G\n\tprincipal\x18\x03 \x01(\x0b\x32\x1b.cerbos.engine.v1.PrincipalB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\tprincipal\x12\x44\n\x08resource\x18\x04 \x01(\x0b\x32\x1a.cerbos.engine.v1.ResourceB\x0c\xe2\x41\x01\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08resource\x12n\n\x07\x61\x63tions\x18\x05 \x03(\tBT\x92\x41;20List of actions being performed on the resource.\xa0\x01\x32\xa8\x01\x01\xb0\x01\x01\xe2\x41\x01\x02\xfa\x42\x0f\x92\x01\x0c\x08\x01\x10\x32\x18\x01\"\x04r\x02\x10\x01R\x07\x61\x63tions\x12\x35\n\x08\x61ux_data\x18\x06 \x01(\x0b\x32\x1a.cerbos.request.v1.AuxDataR\x07\x61uxData:\"\x92\x41\x1f\n\x1d\x32\x1bPlayground evaluate request\"\xb1\x04\n\x16PlaygroundProxyRequest\x12#\n\rplayground_id\x18\x01 \x01(\tR\x0cplaygroundId\x12V\n\x05\x66iles\x18\x02 \x03(\x0b\x32\x17.cerbos.request.v1.FileB\'\x92\x41\x16\x32\x0eList of files.\xa0\x01\x1e\xa8\x01\x01\xe2\x41\x01\x02\xfa\x42\x07\x92\x01\x04\x08\x01\x10\x1eR\x05\x66iles\x12Z\n\x12\x63heck_resource_set\x18\x03 \x01(\x0b\x32*.cerbos.request.v1.CheckResourceSetRequestH\x00R\x10\x63heckResourceSet\x12`\n\x14\x63heck_resource_batch\x18\x04 \x01(\x0b\x32,.cerbos.request.v1.CheckResourceBatchRequestH\x00R\x12\x63heckResourceBatch\x12P\n\x0eplan_resources\x18\x05 \x01(\x0b\x32\'.cerbos.request.v1.PlanResourcesRequestH\x00R\rplanResources\x12S\n\x0f\x63heck_resources\x18\x06 \x01(\x0b\x32(.cerbos.request.v1.CheckResourcesRequestH\x00R\x0e\x63heckResources:\x1f\x92\x41\x1c\n\x1a\x32\x18Playground proxy requestB\x14\n\rproxy_request\x12\x03\xf8\x42\x01\"\x9e\x01\n\x18\x41\x64\x64OrUpdatePolicyRequest\x12`\n\x08policies\x18\x01 \x03(\x0b\x32\x18.cerbos.policy.v1.PolicyB*\x92\x41\x19\x32\x11List of policies.\xa0\x01\n\xa8\x01\x01\xe2\x41\x01\x02\xfa\x42\x07\x92\x01\x04\x08\x01\x10\nR\x08policies: \x92\x41\x1d\n\x1b\x32\x19\x41\x64\x64/update policy request\"\xa5\x07\n\x1aListAuditLogEntriesRequest\x12\x86\x01\n\x04kind\x18\x01 \x01(\x0e\x32\x32.cerbos.request.v1.ListAuditLogEntriesRequest.KindB>\x92\x41\x31\x32\x11Kind of log entry\xf2\x02\x0bKIND_ACCESS\xf2\x02\rKIND_DECISION\xfa\x42\x07\x82\x01\x04\x18\x01\x18\x02R\x04kind\x12\x44\n\x04tail\x18\x02 \x01(\rB.\x92\x41#2\x0fLast N entries.Y\x00\x00\x00\x00\x00@\x8f@i\x00\x00\x00\x00\x00\x00\xf0?\xfa\x42\x05*\x03\x18\xe8\x07H\x00R\x04tail\x12S\n\x07\x62\x65tween\x18\x03 \x01(\x0b\x32\x37.cerbos.request.v1.ListAuditLogEntriesRequest.TimeRangeH\x00R\x07\x62\x65tween\x12Y\n\x05since\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB&\x92\x41#2!Entries since N hours/minutes agoH\x00R\x05since\x12\x83\x01\n\x06lookup\x18\x05 \x01(\tBi\x92\x41\x37\x32\nBy Call ID\x8a\x01(^[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\xfa\x42,r*2(^[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$H\x00R\x06lookup\x1a\xb0\x02\n\tTimeRange\x12\x80\x01\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampBN\x92\x41=2\x1eStart date in ISO 8601 format.J\x1b\"2021-07-05T07:27:01+00:00\"\xe2\x41\x01\x02\xfa\x42\x07\xb2\x01\x04\x08\x01\x38\x01R\x05start\x12z\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBL\x92\x41;2\x1c\x45nd date in ISO 8601 format.J\x1b\"2021-07-05T07:27:01+00:00\"\xe2\x41\x01\x02\xfa\x42\x07\xb2\x01\x04\x08\x01\x38\x01R\x03\x65nd:$\x92\x41!\n\x1f\x32\x1d\x45ntries between a time range.\"@\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x0f\n\x0bKIND_ACCESS\x10\x01\x12\x11\n\rKIND_DECISION\x10\x02\x42\r\n\x06\x66ilter\x12\x03\xf8\x42\x01\"/\n\x11ServerInfoRequest:\x1a\x92\x41\x17\n\x15\x32\x13Server info request\"\xfb\x02\n\x13ListPoliciesRequest\x12M\n\x10include_disabled\x18\x01 \x01(\x08\x42\"\x92\x41\x1b\x32\x19Include disabled policies\xe2\x41\x01\x01R\x0fincludeDisabled\x12M\n\x0bname_regexp\x18\x02 \x01(\tB,\x92\x41%2#Filter policies by name with regexp\xe2\x41\x01\x01R\nnameRegexp\x12P\n\x0cscope_regexp\x18\x03 \x01(\tB-\x92\x41&2$Filter policies by scope with regexp\xe2\x41\x01\x01R\x0bscopeRegexp\x12V\n\x0eversion_regexp\x18\x04 \x01(\tB/\x92\x41(2&Filter policies by version with regexp\xe2\x41\x01\x01R\rversionRegexp:\x1c\x92\x41\x19\n\x17\x32\x15List policies request\"\x84\x02\n\x10GetPolicyRequest\x12\xd4\x01\n\x02id\x18\x01 \x03(\tB\xc3\x01\x92\x41\xa6\x01\x32\x87\x01\x46or blob, disk, git stores use file name (<filename>.yaml). For mysql, postgres, sqlite3 use id (<kind>.<name>.<version>) of the policyJ\x1a\"principal.sarah.vdefault\"\xe2\x41\x01\x02\xfa\x42\x12\x92\x01\x0f\x08\x01\x10\x19\x18\x01\"\x07r\x05\x10\x01\x18\x80\nR\x02id:\x19\x92\x41\x16\n\x14\x32\x12Get policy request\"\xa1\x01\n\x14\x44isablePolicyRequest\x12j\n\x02id\x18\x01 \x03(\tBZ\x92\x41>2 Unique identifier for the policyJ\x1a\"principal.sarah.vdefault\"\xe2\x41\x01\x02\xfa\x42\x12\x92\x01\x0f\x08\x01\x10\x19\x18\x01\"\x07r\x05\x10\x01\x18\x80\nR\x02id:\x1d\x92\x41\x1a\n\x18\x32\x16\x44isable policy request\"\x9f\x01\n\x13\x45nablePolicyRequest\x12j\n\x02id\x18\x01 \x03(\tBZ\x92\x41>2 Unique identifier for the policyJ\x1a\"principal.sarah.vdefault\"\xe2\x41\x01\x02\xfa\x42\x12\x92\x01\x0f\x08\x01\x10\x19\x18\x01\"\x07r\x05\x10\x01\x18\x80\nR\x02id:\x1c\x92\x41\x19\n\x17\x32\x15\x45nable policy request\"\x9b\x01\n\x18\x41\x64\x64OrUpdateSchemaRequest\x12]\n\x07schemas\x18\x01 \x03(\x0b\x32\x18.cerbos.schema.v1.SchemaB)\x92\x41\x18\x32\x10List of schemas.\xa0\x01\n\xa8\x01\x01\xe2\x41\x01\x02\xfa\x42\x07\x92\x01\x04\x08\x01\x10\nR\x07schemas: \x92\x41\x1d\n\x1b\x32\x19\x41\x64\x64/update schema request\"4\n\x12ListSchemasRequest:\x1e\x92\x41\x1b\n\x19\x32\x17List schema ids request\"\x92\x01\n\x10GetSchemaRequest\x12`\n\x02id\x18\x01 \x03(\tBP\x92\x41\x34\x32 Unique identifier for the schemaJ\x10\"principal.json\"\xe2\x41\x01\x02\xfa\x42\x12\x92\x01\x0f\x08\x01\x10\x19\x18\x01\"\x07r\x05\x10\x01\x18\xff\x01R\x02id:\x1c\x92\x41\x19\n\x17\x32\x15Get schema(s) request\"\x98\x01\n\x13\x44\x65leteSchemaRequest\x12`\n\x02id\x18\x01 \x03(\tBP\x92\x41\x34\x32 Unique identifier for the schemaJ\x10\"principal.json\"\xe2\x41\x01\x02\xfa\x42\x12\x92\x01\x0f\x08\x01\x10\x19\x18\x01\"\x07r\x05\x10\x01\x18\xff\x01R\x02id:\x1f\x92\x41\x1c\n\x1a\x32\x18\x44\x65lete schema(s) request\"z\n\x12ReloadStoreRequest\x12G\n\x04wait\x18\x01 \x01(\x08\x42\x33\x92\x41,2*Wait until the reloading process finalizes\xe2\x41\x01\x01R\x04wait:\x1b\x92\x41\x18\n\x16\x32\x14Reload store requestBs\n\x19\x64\x65v.cerbos.api.v1.requestZ>github.com/cerbos/cerbos/api/genpb/cerbos/request/v1;requestv1\xaa\x02\x15\x43\x65rbos.Api.V1.Requestb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.request.v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031dev.cerbos.api.v1.requestZ>github.com/cerbos/cerbos/api/genpb/cerbos/request/v1;requestv1\252\002\025Cerbos.Api.V1.Request'
  _PLANRESOURCESREQUEST.fields_by_name['request_id']._options = None
  _PLANRESOURCESREQUEST.fields_by_name['request_id']._serialized_options = b'\222At2JOptional application-specific ID useful for correlating logs for analysis.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _PLANRESOURCESREQUEST.fields_by_name['action']._options = None
  _PLANRESOURCESREQUEST.fields_by_name['action']._serialized_options = b'\222AC22Action to be applied to each resource in the list.J\r\"view:public\"\342A\001\002\372B\004r\002\020\001'
  _PLANRESOURCESREQUEST.fields_by_name['principal']._options = None
  _PLANRESOURCESREQUEST.fields_by_name['principal']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _PLANRESOURCESREQUEST.fields_by_name['resource']._options = None
  _PLANRESOURCESREQUEST.fields_by_name['resource']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _PLANRESOURCESREQUEST.fields_by_name['aux_data']._options = None
  _PLANRESOURCESREQUEST.fields_by_name['aux_data']._serialized_options = b'\342A\001\001'
  _PLANRESOURCESREQUEST.fields_by_name['include_meta']._options = None
  _PLANRESOURCESREQUEST.fields_by_name['include_meta']._serialized_options = b'\222A=2;Opt to receive request processing metadata in the response.'
  _PLANRESOURCESREQUEST._options = None
  _PLANRESOURCESREQUEST._serialized_options = b'\222A$\n\"2 PDP Resources Query Plan Request'
  _CHECKRESOURCESETREQUEST.fields_by_name['request_id']._options = None
  _CHECKRESOURCESETREQUEST.fields_by_name['request_id']._serialized_options = b'\222At2JOptional application-specific ID useful for correlating logs for analysis.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCESETREQUEST.fields_by_name['actions']._options = None
  _CHECKRESOURCESETREQUEST.fields_by_name['actions']._serialized_options = b'\222A\\28List of actions being performed on the set of resources.J\032[\"view:public\", \"comment\"]\250\001\001\260\001\001\342A\001\002\372B\r\222\001\n\010\001\030\001\"\004r\002\020\001'
  _CHECKRESOURCESETREQUEST.fields_by_name['principal']._options = None
  _CHECKRESOURCESETREQUEST.fields_by_name['principal']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _CHECKRESOURCESETREQUEST.fields_by_name['resource']._options = None
  _CHECKRESOURCESETREQUEST.fields_by_name['resource']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _CHECKRESOURCESETREQUEST.fields_by_name['include_meta']._options = None
  _CHECKRESOURCESETREQUEST.fields_by_name['include_meta']._serialized_options = b'\222A=2;Opt to receive request processing metadata in the response.'
  _CHECKRESOURCESETREQUEST.fields_by_name['aux_data']._options = None
  _CHECKRESOURCESETREQUEST.fields_by_name['aux_data']._serialized_options = b'\342A\001\001'
  _CHECKRESOURCESETREQUEST._options = None
  _CHECKRESOURCESETREQUEST._serialized_options = b'\222A\017\n\r2\013PDP Request'
  _RESOURCESET_INSTANCESENTRY._options = None
  _RESOURCESET_INSTANCESENTRY._serialized_options = b'8\001'
  _RESOURCESET.fields_by_name['kind']._options = None
  _RESOURCESET.fields_by_name['kind']._serialized_options = b'\222Ab2\016Resource kind.J\016\"album:object\"\212\001?^[[:alpha:]][[:word:]\\@\\.\\-]*(\\:[[:alpha:]][[:word:]\\@\\.\\-]*)*$\342A\001\002\372BGrE\020\0012A^[[:alpha:]][[:word:]\\@\\.\\-/]*(\\:[[:alpha:]][[:word:]\\@\\.\\-/]*)*$'
  _RESOURCESET.fields_by_name['policy_version']._options = None
  _RESOURCESET.fields_by_name['policy_version']._serialized_options = b'\222A\231\0012|The policy version to use to evaluate this request. If not specified, will default to the server-configured default version.J\t\"default\"\212\001\r^[[:word:]]*$\342A\001\001\372B\021r\0172\r^[[:word:]]*$'
  _RESOURCESET.fields_by_name['instances']._options = None
  _RESOURCESET.fields_by_name['instances']._serialized_options = b'\222A\214\0022mSet of resource instances to check. Each instance must be keyed by an application-specific unique identifier.J\227\001{\"XX125\":{\"attr\":{\"owner\":\"bugs_bunny\", \"public\": false, \"flagged\": false}}, \"XX225\":{\"attr\":{\"owner\":\"daffy_duck\", \"public\": true, \"flagged\": false}}}\310\001\001\342A\001\002\372B\007\232\001\004\010\001\030\001'
  _RESOURCESET.fields_by_name['scope']._options = None
  _RESOURCESET.fields_by_name['scope']._serialized_options = b'\222A\262\0012~A dot-separated scope that describes the hierarchy these resources belong to. This is used for determining policy inheritance.\212\001/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$\342A\001\001\372B3r12/^([[:alnum:]][[:word:]\\-]*(\\.[[:word:]\\-]*)*)*$'
  _RESOURCESET._options = None
  _RESOURCESET._serialized_options = b'\222A\035\n\0332\031Set of resources to check'
  _ATTRIBUTESMAP_ATTRENTRY._options = None
  _ATTRIBUTESMAP_ATTRENTRY._serialized_options = b'8\001'
  _ATTRIBUTESMAP.fields_by_name['attr']._options = None
  _ATTRIBUTESMAP.fields_by_name['attr']._serialized_options = b'\222Af2dKey-value pairs of contextual data about this instance that should be used during policy evaluation.\372B\005\232\001\002\030\001'
  _ATTRIBUTESMAP._options = None
  _ATTRIBUTESMAP._serialized_options = b'\222A0\n.2,Unique identifier for the resource instance.'
  _CHECKRESOURCEBATCHREQUEST_BATCHENTRY.fields_by_name['actions']._options = None
  _CHECKRESOURCEBATCHREQUEST_BATCHENTRY.fields_by_name['actions']._serialized_options = b'\222AT20List of actions being performed on the resource.J\032[\"view:public\", \"comment\"]\250\001\001\260\001\001\342A\001\002\372B\r\222\001\n\010\001\030\001\"\004r\002\020\001'
  _CHECKRESOURCEBATCHREQUEST_BATCHENTRY.fields_by_name['resource']._options = None
  _CHECKRESOURCEBATCHREQUEST_BATCHENTRY.fields_by_name['resource']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _CHECKRESOURCEBATCHREQUEST.fields_by_name['request_id']._options = None
  _CHECKRESOURCEBATCHREQUEST.fields_by_name['request_id']._serialized_options = b'\222At2JOptional application-specific ID useful for correlating logs for analysis.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCEBATCHREQUEST.fields_by_name['principal']._options = None
  _CHECKRESOURCEBATCHREQUEST.fields_by_name['principal']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _CHECKRESOURCEBATCHREQUEST.fields_by_name['resources']._options = None
  _CHECKRESOURCEBATCHREQUEST.fields_by_name['resources']._serialized_options = b'\222A\325\0012\036List of resources and actions.J\254\001[{\"actions\":[\"view\",\"comment\"], \"resource\":{\"kind\":\"album:object\",\"policyVersion\":\"default\",\"id\":\"XX125\",\"attr\":{\"owner\":\"bugs_bunny\", \"public\": false, \"flagged\": false}}}]\250\001\001\260\001\001\342A\001\002\372B\005\222\001\002\010\001'
  _CHECKRESOURCEBATCHREQUEST._options = None
  _CHECKRESOURCEBATCHREQUEST._serialized_options = b'\222A\017\n\r2\013PDP Request'
  _CHECKRESOURCESREQUEST_RESOURCEENTRY.fields_by_name['actions']._options = None
  _CHECKRESOURCESREQUEST_RESOURCEENTRY.fields_by_name['actions']._serialized_options = b'\222AT20List of actions being performed on the resource.J\032[\"view:public\", \"comment\"]\250\001\001\260\001\001\342A\001\002\372B\r\222\001\n\010\001\030\001\"\004r\002\020\001'
  _CHECKRESOURCESREQUEST_RESOURCEENTRY.fields_by_name['resource']._options = None
  _CHECKRESOURCESREQUEST_RESOURCEENTRY.fields_by_name['resource']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _CHECKRESOURCESREQUEST.fields_by_name['request_id']._options = None
  _CHECKRESOURCESREQUEST.fields_by_name['request_id']._serialized_options = b'\222At2JOptional application-specific ID useful for correlating logs for analysis.J&\"c2db17b8-4f9f-4fb1-acfd-9162a02be42b\"'
  _CHECKRESOURCESREQUEST.fields_by_name['include_meta']._options = None
  _CHECKRESOURCESREQUEST.fields_by_name['include_meta']._serialized_options = b'\222A220Add request processing metadata to the response.'
  _CHECKRESOURCESREQUEST.fields_by_name['principal']._options = None
  _CHECKRESOURCESREQUEST.fields_by_name['principal']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _CHECKRESOURCESREQUEST.fields_by_name['resources']._options = None
  _CHECKRESOURCESREQUEST.fields_by_name['resources']._serialized_options = b'\222A\325\0012\036List of resources and actions.J\254\001[{\"actions\":[\"view\",\"comment\"], \"resource\":{\"kind\":\"album:object\",\"policyVersion\":\"default\",\"id\":\"XX125\",\"attr\":{\"owner\":\"bugs_bunny\", \"public\": false, \"flagged\": false}}}]\250\001\001\260\001\001\342A\001\002\372B\005\222\001\002\010\001'
  _CHECKRESOURCESREQUEST._options = None
  _CHECKRESOURCESREQUEST._serialized_options = b'\222A\033\n\0312\027Check resources request'
  _AUXDATA_JWT.fields_by_name['token']._options = None
  _AUXDATA_JWT.fields_by_name['token']._serialized_options = b'\222A\353\0032\035JWT from the original requestJ\311\003\"eyJhbGciOiJFUzM4NCIsImtpZCI6IjE5TGZaYXRFZGc4M1lOYzVyMjNndU1KcXJuND0iLCJ0eXAiOiJKV1QifQ.eyJhdWQiOlsiY2VyYm9zLWp3dC10ZXN0cyJdLCJjdXN0b21BcnJheSI6WyJBIiwiQiIsIkMiXSwiY3VzdG9tSW50Ijo0MiwiY3VzdG9tTWFwIjp7IkEiOiJBQSIsIkIiOiJCQiIsIkMiOiJDQyJ9LCJjdXN0b21TdHJpbmciOiJmb29iYXIiLCJleHAiOjE5NDk5MzQwMzksImlzcyI6ImNlcmJvcy10ZXN0LXN1aXRlIn0.WN_tOScSpd_EI-P5EI1YlagxEgExSfBjAtcrgcF6lyWj1lGpR_GKx9goZEp2p_t5AVWXN_bjz_sMUmJdJa4cVd55Qm1miR-FKu6oNRHnSEWdMFmnArwPw-YDJWfylLFX\"\342A\001\002\372B\004r\002\020\001'
  _AUXDATA_JWT.fields_by_name['key_set_id']._options = None
  _AUXDATA_JWT.fields_by_name['key_set_id']._serialized_options = b'\222Aa2RKey ID to use when decoding the token (defined in the Cerbos server configuration)J\013\"my-keyset\"'
  _AUXDATA_JWT._options = None
  _AUXDATA_JWT._serialized_options = b'\222A!\n\0372\035JWT from the original request'
  _AUXDATA._options = None
  _AUXDATA._serialized_options = b'\222A?\n=2;Structured auxiliary data useful for evaluating the request'
  _FILE.fields_by_name['file_name']._options = None
  _FILE.fields_by_name['file_name']._serialized_options = b'\342A\001\002\372B\004r\002\020\001'
  _FILE.fields_by_name['contents']._options = None
  _FILE.fields_by_name['contents']._serialized_options = b'\342A\001\002\372B\010z\006\020\001\030\200\200@'
  _PLAYGROUNDVALIDATEREQUEST.fields_by_name['files']._options = None
  _PLAYGROUNDVALIDATEREQUEST.fields_by_name['files']._serialized_options = b'\222A\0262\016List of files.\240\001\036\250\001\001\342A\001\002\372B\007\222\001\004\010\001\020\036'
  _PLAYGROUNDVALIDATEREQUEST._options = None
  _PLAYGROUNDVALIDATEREQUEST._serialized_options = b'\222A\037\n\0352\033Playground validate request'
  _PLAYGROUNDTESTREQUEST.fields_by_name['files']._options = None
  _PLAYGROUNDTESTREQUEST.fields_by_name['files']._serialized_options = b'\222A\0262\016List of files.\240\001\036\250\001\001\342A\001\002\372B\007\222\001\004\010\001\020\036'
  _PLAYGROUNDTESTREQUEST._options = None
  _PLAYGROUNDTESTREQUEST._serialized_options = b'\222A\033\n\0312\027Playground test request'
  _PLAYGROUNDEVALUATEREQUEST.fields_by_name['files']._options = None
  _PLAYGROUNDEVALUATEREQUEST.fields_by_name['files']._serialized_options = b'\222A\0262\016List of files.\240\001\036\250\001\001\342A\001\002\372B\007\222\001\004\010\001\020\036'
  _PLAYGROUNDEVALUATEREQUEST.fields_by_name['principal']._options = None
  _PLAYGROUNDEVALUATEREQUEST.fields_by_name['principal']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _PLAYGROUNDEVALUATEREQUEST.fields_by_name['resource']._options = None
  _PLAYGROUNDEVALUATEREQUEST.fields_by_name['resource']._serialized_options = b'\342A\001\002\372B\005\212\001\002\020\001'
  _PLAYGROUNDEVALUATEREQUEST.fields_by_name['actions']._options = None
  _PLAYGROUNDEVALUATEREQUEST.fields_by_name['actions']._serialized_options = b'\222A;20List of actions being performed on the resource.\240\0012\250\001\001\260\001\001\342A\001\002\372B\017\222\001\014\010\001\0202\030\001\"\004r\002\020\001'
  _PLAYGROUNDEVALUATEREQUEST._options = None
  _PLAYGROUNDEVALUATEREQUEST._serialized_options = b'\222A\037\n\0352\033Playground evaluate request'
  _PLAYGROUNDPROXYREQUEST.oneofs_by_name['proxy_request']._options = None
  _PLAYGROUNDPROXYREQUEST.oneofs_by_name['proxy_request']._serialized_options = b'\370B\001'
  _PLAYGROUNDPROXYREQUEST.fields_by_name['files']._options = None
  _PLAYGROUNDPROXYREQUEST.fields_by_name['files']._serialized_options = b'\222A\0262\016List of files.\240\001\036\250\001\001\342A\001\002\372B\007\222\001\004\010\001\020\036'
  _PLAYGROUNDPROXYREQUEST._options = None
  _PLAYGROUNDPROXYREQUEST._serialized_options = b'\222A\034\n\0322\030Playground proxy request'
  _ADDORUPDATEPOLICYREQUEST.fields_by_name['policies']._options = None
  _ADDORUPDATEPOLICYREQUEST.fields_by_name['policies']._serialized_options = b'\222A\0312\021List of policies.\240\001\n\250\001\001\342A\001\002\372B\007\222\001\004\010\001\020\n'
  _ADDORUPDATEPOLICYREQUEST._options = None
  _ADDORUPDATEPOLICYREQUEST._serialized_options = b'\222A\035\n\0332\031Add/update policy request'
  _LISTAUDITLOGENTRIESREQUEST_TIMERANGE.fields_by_name['start']._options = None
  _LISTAUDITLOGENTRIESREQUEST_TIMERANGE.fields_by_name['start']._serialized_options = b'\222A=2\036Start date in ISO 8601 format.J\033\"2021-07-05T07:27:01+00:00\"\342A\001\002\372B\007\262\001\004\010\0018\001'
  _LISTAUDITLOGENTRIESREQUEST_TIMERANGE.fields_by_name['end']._options = None
  _LISTAUDITLOGENTRIESREQUEST_TIMERANGE.fields_by_name['end']._serialized_options = b'\222A;2\034End date in ISO 8601 format.J\033\"2021-07-05T07:27:01+00:00\"\342A\001\002\372B\007\262\001\004\010\0018\001'
  _LISTAUDITLOGENTRIESREQUEST_TIMERANGE._options = None
  _LISTAUDITLOGENTRIESREQUEST_TIMERANGE._serialized_options = b'\222A!\n\0372\035Entries between a time range.'
  _LISTAUDITLOGENTRIESREQUEST.oneofs_by_name['filter']._options = None
  _LISTAUDITLOGENTRIESREQUEST.oneofs_by_name['filter']._serialized_options = b'\370B\001'
  _LISTAUDITLOGENTRIESREQUEST.fields_by_name['kind']._options = None
  _LISTAUDITLOGENTRIESREQUEST.fields_by_name['kind']._serialized_options = b'\222A12\021Kind of log entry\362\002\013KIND_ACCESS\362\002\rKIND_DECISION\372B\007\202\001\004\030\001\030\002'
  _LISTAUDITLOGENTRIESREQUEST.fields_by_name['tail']._options = None
  _LISTAUDITLOGENTRIESREQUEST.fields_by_name['tail']._serialized_options = b'\222A#2\017Last N entries.Y\000\000\000\000\000@\217@i\000\000\000\000\000\000\360?\372B\005*\003\030\350\007'
  _LISTAUDITLOGENTRIESREQUEST.fields_by_name['since']._options = None
  _LISTAUDITLOGENTRIESREQUEST.fields_by_name['since']._serialized_options = b'\222A#2!Entries since N hours/minutes ago'
  _LISTAUDITLOGENTRIESREQUEST.fields_by_name['lookup']._options = None
  _LISTAUDITLOGENTRIESREQUEST.fields_by_name['lookup']._serialized_options = b'\222A72\nBy Call ID\212\001(^[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\372B,r*2(^[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$'
  _SERVERINFOREQUEST._options = None
  _SERVERINFOREQUEST._serialized_options = b'\222A\027\n\0252\023Server info request'
  _LISTPOLICIESREQUEST.fields_by_name['include_disabled']._options = None
  _LISTPOLICIESREQUEST.fields_by_name['include_disabled']._serialized_options = b'\222A\0332\031Include disabled policies\342A\001\001'
  _LISTPOLICIESREQUEST.fields_by_name['name_regexp']._options = None
  _LISTPOLICIESREQUEST.fields_by_name['name_regexp']._serialized_options = b'\222A%2#Filter policies by name with regexp\342A\001\001'
  _LISTPOLICIESREQUEST.fields_by_name['scope_regexp']._options = None
  _LISTPOLICIESREQUEST.fields_by_name['scope_regexp']._serialized_options = b'\222A&2$Filter policies by scope with regexp\342A\001\001'
  _LISTPOLICIESREQUEST.fields_by_name['version_regexp']._options = None
  _LISTPOLICIESREQUEST.fields_by_name['version_regexp']._serialized_options = b'\222A(2&Filter policies by version with regexp\342A\001\001'
  _LISTPOLICIESREQUEST._options = None
  _LISTPOLICIESREQUEST._serialized_options = b'\222A\031\n\0272\025List policies request'
  _GETPOLICYREQUEST.fields_by_name['id']._options = None
  _GETPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\222A\246\0012\207\001For blob, disk, git stores use file name (<filename>.yaml). For mysql, postgres, sqlite3 use id (<kind>.<name>.<version>) of the policyJ\032\"principal.sarah.vdefault\"\342A\001\002\372B\022\222\001\017\010\001\020\031\030\001\"\007r\005\020\001\030\200\n'
  _GETPOLICYREQUEST._options = None
  _GETPOLICYREQUEST._serialized_options = b'\222A\026\n\0242\022Get policy request'
  _DISABLEPOLICYREQUEST.fields_by_name['id']._options = None
  _DISABLEPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\222A>2 Unique identifier for the policyJ\032\"principal.sarah.vdefault\"\342A\001\002\372B\022\222\001\017\010\001\020\031\030\001\"\007r\005\020\001\030\200\n'
  _DISABLEPOLICYREQUEST._options = None
  _DISABLEPOLICYREQUEST._serialized_options = b'\222A\032\n\0302\026Disable policy request'
  _ENABLEPOLICYREQUEST.fields_by_name['id']._options = None
  _ENABLEPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\222A>2 Unique identifier for the policyJ\032\"principal.sarah.vdefault\"\342A\001\002\372B\022\222\001\017\010\001\020\031\030\001\"\007r\005\020\001\030\200\n'
  _ENABLEPOLICYREQUEST._options = None
  _ENABLEPOLICYREQUEST._serialized_options = b'\222A\031\n\0272\025Enable policy request'
  _ADDORUPDATESCHEMAREQUEST.fields_by_name['schemas']._options = None
  _ADDORUPDATESCHEMAREQUEST.fields_by_name['schemas']._serialized_options = b'\222A\0302\020List of schemas.\240\001\n\250\001\001\342A\001\002\372B\007\222\001\004\010\001\020\n'
  _ADDORUPDATESCHEMAREQUEST._options = None
  _ADDORUPDATESCHEMAREQUEST._serialized_options = b'\222A\035\n\0332\031Add/update schema request'
  _LISTSCHEMASREQUEST._options = None
  _LISTSCHEMASREQUEST._serialized_options = b'\222A\033\n\0312\027List schema ids request'
  _GETSCHEMAREQUEST.fields_by_name['id']._options = None
  _GETSCHEMAREQUEST.fields_by_name['id']._serialized_options = b'\222A42 Unique identifier for the schemaJ\020\"principal.json\"\342A\001\002\372B\022\222\001\017\010\001\020\031\030\001\"\007r\005\020\001\030\377\001'
  _GETSCHEMAREQUEST._options = None
  _GETSCHEMAREQUEST._serialized_options = b'\222A\031\n\0272\025Get schema(s) request'
  _DELETESCHEMAREQUEST.fields_by_name['id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['id']._serialized_options = b'\222A42 Unique identifier for the schemaJ\020\"principal.json\"\342A\001\002\372B\022\222\001\017\010\001\020\031\030\001\"\007r\005\020\001\030\377\001'
  _DELETESCHEMAREQUEST._options = None
  _DELETESCHEMAREQUEST._serialized_options = b'\222A\034\n\0322\030Delete schema(s) request'
  _RELOADSTOREREQUEST.fields_by_name['wait']._options = None
  _RELOADSTOREREQUEST.fields_by_name['wait']._serialized_options = b'\222A,2*Wait until the reloading process finalizes\342A\001\001'
  _RELOADSTOREREQUEST._options = None
  _RELOADSTOREREQUEST._serialized_options = b'\222A\030\n\0262\024Reload store request'
  _globals['_PLANRESOURCESREQUEST']._serialized_start=349
  _globals['_PLANRESOURCESREQUEST']._serialized_end=996
  _globals['_CHECKRESOURCESETREQUEST']._serialized_start=999
  _globals['_CHECKRESOURCESETREQUEST']._serialized_end=1650
  _globals['_RESOURCESET']._serialized_start=1653
  _globals['_RESOURCESET']._serialized_end=2856
  _globals['_RESOURCESET_INSTANCESENTRY']._serialized_start=2728
  _globals['_RESOURCESET_INSTANCESENTRY']._serialized_end=2822
  _globals['_ATTRIBUTESMAP']._serialized_start=2859
  _globals['_ATTRIBUTESMAP']._serialized_end=3188
  _globals['_ATTRIBUTESMAP_ATTRENTRY']._serialized_start=3056
  _globals['_ATTRIBUTESMAP_ATTRENTRY']._serialized_end=3135
  _globals['_CHECKRESOURCEBATCHREQUEST']._serialized_start=3191
  _globals['_CHECKRESOURCEBATCHREQUEST']._serialized_end=4060
  _globals['_CHECKRESOURCEBATCHREQUEST_BATCHENTRY']._serialized_start=3822
  _globals['_CHECKRESOURCEBATCHREQUEST_BATCHENTRY']._serialized_end=4040
  _globals['_CHECKRESOURCESREQUEST']._serialized_start=4063
  _globals['_CHECKRESOURCESREQUEST']._serialized_end=5032
  _globals['_CHECKRESOURCESREQUEST_RESOURCEENTRY']._serialized_start=4779
  _globals['_CHECKRESOURCESREQUEST_RESOURCEENTRY']._serialized_end=5000
  _globals['_AUXDATA']._serialized_start=5035
  _globals['_AUXDATA']._serialized_end=5873
  _globals['_AUXDATA_JWT']._serialized_start=5097
  _globals['_AUXDATA_JWT']._serialized_end=5805
  _globals['_FILE']._serialized_start=5875
  _globals['_FILE']._serialized_end=5968
  _globals['_PLAYGROUNDVALIDATEREQUEST']._serialized_start=5971
  _globals['_PLAYGROUNDVALIDATEREQUEST']._serialized_end=6159
  _globals['_PLAYGROUNDTESTREQUEST']._serialized_start=6162
  _globals['_PLAYGROUNDTESTREQUEST']._serialized_end=6342
  _globals['_PLAYGROUNDEVALUATEREQUEST']._serialized_start=6345
  _globals['_PLAYGROUNDEVALUATEREQUEST']._serialized_end=6843
  _globals['_PLAYGROUNDPROXYREQUEST']._serialized_start=6846
  _globals['_PLAYGROUNDPROXYREQUEST']._serialized_end=7407
  _globals['_ADDORUPDATEPOLICYREQUEST']._serialized_start=7410
  _globals['_ADDORUPDATEPOLICYREQUEST']._serialized_end=7568
  _globals['_LISTAUDITLOGENTRIESREQUEST']._serialized_start=7571
  _globals['_LISTAUDITLOGENTRIESREQUEST']._serialized_end=8504
  _globals['_LISTAUDITLOGENTRIESREQUEST_TIMERANGE']._serialized_start=8119
  _globals['_LISTAUDITLOGENTRIESREQUEST_TIMERANGE']._serialized_end=8423
  _globals['_LISTAUDITLOGENTRIESREQUEST_KIND']._serialized_start=8425
  _globals['_LISTAUDITLOGENTRIESREQUEST_KIND']._serialized_end=8489
  _globals['_SERVERINFOREQUEST']._serialized_start=8506
  _globals['_SERVERINFOREQUEST']._serialized_end=8553
  _globals['_LISTPOLICIESREQUEST']._serialized_start=8556
  _globals['_LISTPOLICIESREQUEST']._serialized_end=8935
  _globals['_GETPOLICYREQUEST']._serialized_start=8938
  _globals['_GETPOLICYREQUEST']._serialized_end=9198
  _globals['_DISABLEPOLICYREQUEST']._serialized_start=9201
  _globals['_DISABLEPOLICYREQUEST']._serialized_end=9362
  _globals['_ENABLEPOLICYREQUEST']._serialized_start=9365
  _globals['_ENABLEPOLICYREQUEST']._serialized_end=9524
  _globals['_ADDORUPDATESCHEMAREQUEST']._serialized_start=9527
  _globals['_ADDORUPDATESCHEMAREQUEST']._serialized_end=9682
  _globals['_LISTSCHEMASREQUEST']._serialized_start=9684
  _globals['_LISTSCHEMASREQUEST']._serialized_end=9736
  _globals['_GETSCHEMAREQUEST']._serialized_start=9739
  _globals['_GETSCHEMAREQUEST']._serialized_end=9885
  _globals['_DELETESCHEMAREQUEST']._serialized_start=9888
  _globals['_DELETESCHEMAREQUEST']._serialized_end=10040
  _globals['_RELOADSTOREREQUEST']._serialized_start=10042
  _globals['_RELOADSTOREREQUEST']._serialized_end=10164
# @@protoc_insertion_point(module_scope)
